<?php
include('php/dbconn.php');

session_start(); // Start the session

// Check if the user is logged in
if (!isset($_SESSION['user'])) {
    // Redirect to login page if not logged in
    header('Location: login_1.php');
    exit;
}

// Query to get the number of visitors today from both visitor_details and walkin_visitors tables
$sql_today = "
    SELECT COUNT(*) 
    FROM (
        SELECT 1 FROM visitors WHERE DATE(Plan_Date_Time_In) = CURDATE()
        UNION ALL
        SELECT 1 FROM walkin_visitors WHERE DATE(visit_date) = CURDATE()
    ) AS combined_visitors";
$query_today = mysqli_query($db, $sql_today);
$visitorsTodayCount = mysqli_fetch_array($query_today)[0];

// Query to get the number of visitors arrived today from both visitor_details and walkin_visitors tables
$sql_arrive = "
    SELECT COUNT(*) 
    FROM (
        SELECT 1 FROM visitor_details WHERE DATE(Arrive) = CURDATE()
        UNION ALL
        SELECT 1 FROM walkin_visitors WHERE DATE(Arrive) = CURDATE()
    ) AS arrived_visitors";
$query_arrive = mysqli_query($db, $sql_arrive);
$visitorsArriveCount = mysqli_fetch_array($query_arrive)[0];

// Query to get the number of visitors who have left today from both visitor_details and walkin_visitors tables
$sql_leave = "
    SELECT COUNT(*) 
    FROM (
        SELECT 1 FROM visitor_details WHERE DATE(Leave_Time) = CURDATE()
        UNION ALL
        SELECT 1 FROM walkin_visitors WHERE DATE(Leave_Time) = CURDATE()
    ) AS left_visitors";
$query_leave = mysqli_query($db, $sql_leave);
$visitorsLeaveCount = mysqli_fetch_array($query_leave)[0];

// Query to get the number of pending arrival requests from both visitor_details and walkin_visitors tables
$sql_pending_arrival = "
    SELECT COUNT(*) 
    FROM (
        SELECT 1 FROM visitor_details WHERE Status = 'pending' AND Leave_Time IS NULL
        UNION ALL
        SELECT 1 FROM walkin_visitors WHERE Status = 'pending' AND Leave_Time IS NULL
    ) AS pending_arrival_visitors";
$query_pending_arrival = mysqli_query($db, $sql_pending_arrival);
$pendingArrivalCount = mysqli_fetch_array($query_pending_arrival)[0];

// Query to get the number of pending approval requests (only from visitors table)
$sql_pending_approval = "SELECT COUNT(*) FROM visitors WHERE Status = 'pending'"; 
$query_pending_approval = mysqli_query($db, $sql_pending_approval);
$pendingApprovalCount = mysqli_fetch_array($query_pending_approval)[0];

?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8">
    <title>VMS</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="">
    <meta name="author" content="">

    <!-- CSS Files -->
    <link rel="stylesheet" href="assets/css/style.css">
    <link rel="stylesheet" href="assets/css/loader-style.css">
    <link rel="stylesheet" href="assets/css/bootstrap.css">
    <link rel="stylesheet" href="css/custom.css">
    <link rel="stylesheet" type="text/css" href="assets/js/progress-bar/number-pb.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style type="text/css">
        /* Styling for the page */
        body {
            text-align: center;
            background-size: cover;
            background-repeat: no-repeat;
            font-family: 'Poppins', sans-serif;
            color: white;
            background-image: url(assets/img/bgredbrown.png);
        }

        .bevel.tlbr {
            margin: 0px;
            background: #f0f3f4;
        }

        .card {
            display: flex;               /* Use flexbox for equal height alignment */
            flex-direction: column;      /* Stack the card's content vertically */
            justify-content: space-between; /* Ensure even distribution of space */
            margin: 10px;
            padding: 20px;
            border-radius: 8px;
            background-color: rgba(0, 0, 0, 0.7); /* Dark background with transparency */
            height: 200px;               /* Set a fixed height for all cards */
            width: 100%;                 /* Make the cards take full width of their container */
            max-width: 270px;            /* Limit the card width */
            text-align: center;
            box-sizing: border-box;      /* Ensure padding is included in the card's width and height */
        }

        .card .headline {
            flex-grow: 0;                /* Prevent headline section from growing */
        }

        .card .value {
            flex-grow: 1;                /* Allow value section to grow and take the available space */
            color: #ffcc00;
            font-size: 30px;
            font-weight: bold;
        }

        .card .progress-tinny {
            flex-grow: 0;                /* Prevent progress bar from growing */
            margin-top: 10px;
        }

         .card .icon {
           font-size: 30px;
           color: white;
           margin-bottom: 10px;         /* Space between icon and value */
          }
          
           .card .headline {
            font-size: 18px;
            color: #fff;
        }

    </style>

    <link rel="shortcut icon" href="assets/ico/minus.png">
</head>

<body>
    <!-- Navbar -->
    <?php include('topbar.php'); ?>
    <!-- /END OF TOP NAVBAR -->

    <!-- SIDE MENU -->
    <?php include('sidebar_1.php'); ?>
    <!-- END OF SIDE MENU -->

    <!-- PAPER WRAP -->
    <div class="wrap-fluid">
        <div class="container-fluid paper-wrap bevel tlbr">
            <div class="content-wrap">
                <div class="row">
                    <!-- Number of Visitors Today Card -->
                    <div class="col-sm-3">
                        <div class="card">
                            <div class="headline">
                                <h3>
                                    <span><i class="entypo-users"></i> Number of Visitors Today</span>
                                </h3>
                            </div>
                            <div class="value">
                                <span><?php echo $visitorsTodayCount; ?></span>
                            </div>
                            <div class="progress-tinny">
                                <div style="width: 50%" class="bar"></div>
                            </div>
                        </div>
                    </div>

                    <!-- Number of Visitors Arrived Card -->
                    <div class="col-sm-3">
                        <div class="card">
                            <div class="headline">
                                <h3>
                                    <span><i class="fas fa-door-open"></i> Number of Visitors Arrived</span>
                                </h3>
                            </div>
                            <div class="value">
                                <span><?php echo $visitorsArriveCount; ?></span>
                            </div>
                            <div class="progress-tinny">
                                <div style="width: 50%" class="bar"></div>
                            </div>
                        </div>
                    </div>

                    <!-- Number of Visitors Left Card -->
                    <div class="col-sm-3">
                        <div class="card">
                            <div class="headline">
                                <h3>
                                    <span><i class="fas fa-sign-out-alt"></i> Number of Visitors Left</span>
                                </h3>
                            </div>
                            <div class="value">
                                <span><?php echo $visitorsLeaveCount; ?></span>
                            </div>
                            <div class="progress-tinny">
                                <div style="width: 50%" class="bar"></div>
                            </div>
                        </div>
                    </div>

                    <!-- Pending Approval Card -->
                    <div class="col-sm-3">
                        <div class="card">
                            <div class="headline">
                                <h3>
                                    <span><i class="fas fa-clock"></i> Request Pending Visitor Approval</span>
                                </h3>
                            </div>
                            <div class="value">
                                <span><?php echo $pendingApprovalCount; ?></span>
                            </div>
                            <div class="progress-tinny">
                                <div style="width: 50%" class="bar"></div>
                            </div>
                        </div>
                    </div>

                    <!-- Pending Arrivals Card -->
                    <div class="col-sm-3">
                        <div class="card">
                            <div class="headline">
                                <h3>
                                    <span><i class="fas fa-clock"></i> Awaiting Arrival</span>
                                </h3>
                            </div>
                            <div class="value">
                                <span><?php echo $pendingArrivalCount; ?></span>
                            </div>
                            <div class="progress-tinny">
                                <div style="width: 50%" class="bar"></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- /END OF CONTENT -->

    <!-- FOOTER -->
    <div class="footer-space"></div>
    <div id="footer">
        <div class="devider-footer-left"></div>
        <div class="time">
            <p id="spanDate"></p>
            <p id="clock"></p>
        </div>
        <div class="copyright">Copyright ©2024 All rights reserved | UMC GROUP BERHAD |</div>
        <div class="devider-footer"></div>
    </div>
    <!-- / END OF FOOTER -->

    <!-- Scripts -->
    <script type="text/javascript" src="https://ajax.googleapis.com/ajax/libs/jquery/2.0.0/jquery.js"></script>
    <script src="assets/js/progress-bar/src/jquery.velocity.min.js"></script>
    <script src="assets/js/progress-bar/number-pb.js"></script>
    <script src="assets/js/progress-bar/progress-app.js"></script>
    <script type="text/javascript" src="assets/js/preloader.js"></script>
    <script src="assets/js/bootstrap.js"></script>
    <script src="assets/js/app.js"></script>
    <script src="assets/js/load.js"></script>
    <script src="assets/js/main.js"></script>
</body>

</html>
