<?php
include('dbconn.php');

// Check if the user is logged in
if (!isset($_SESSION['user_id'])) {
    echo "<script>alert('Please log in first.'); location.href='../index.html';</script>";
    exit();
}

// Fetch the logged-in user ID and role
$userId = $_SESSION['user_id'];
$role_name = $_SESSION['role']; // Ensure you have the user role in session

// Determine SQL query based on user role
if ($role_name == 'Admin' || $role_name == 'Guard') {
    // Admin can see all users
    $sql = "SELECT ID, General_Email, Department, Host, Approver, Status FROM visitors";
} else {
    // SQL query to fetch inquiry details based on approver ID
    $sql = "SELECT ID, General_Email, Department, Host, Approver, Status FROM visitors WHERE Approver = ?";
    $stmt = $db->prepare($sql);
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $result = $stmt->get_result();
}

// Execute the SQL query for admin
if ($role_name == 'Admin' || $role_name == 'Guard') {
    $result = $db->query($sql);
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Visitor Details</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style>
        body {
            text-align: center;
            background-size: cover;
            background-repeat: no-repeat;
            color: white;
        }
        table {
            border-collapse: collapse;
            margin: auto;
            width: 80%;
             border: 2px solid grey;
        }
        
        td, th {
            text-align: center;
            padding: 10px;
            font-size: 12px;
            border: 1px solid #ddd;
        }

        th {
            background-color: #f2f2f2;
            color: #333;
            font-weight: bold;
            cursor: pointer;
        }

        tr:nth-child(even) {
            background-color: #f9f9f9;
            color: #333;
        }

        tr:nth-child(odd) {
            background-color: #fff;
            color: #333;
        }

        tr:hover {
            background-color: #f1f1f1;
        }

        /* Search Bar and Column Toggle Container */
        .search-container {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
            margin-left: 10%;
        }

        #globalSearch {
            padding: 8px;
            width: 71%;
            margin-right: 10px;
            border: 1px solid #333;
            border-radius: 5px;
            font-size: 14px;
        }

        #globalSearch:focus {
            border-color: #0056b3;
        }
        
           #printButton{
            padding: 10px 20px;
            font-size: 14px;
            border: none;
            background-color: #0066cc;
            color: white;
            border-radius: 5px;
            cursor: pointer;
            margin-top: 20px;
        }
        #printButton:hover {
            background-color: #444;
        }

        button {
            margin-top: 20px;
            padding: 10px 15px;
            background-color: skyblue;
            color: white;
            border: none;
            cursor: pointer;
            position: relative;
            z-index: 10;
        }

        .filter-container {
            margin: 20px;
        }

        .dropdown {
            position: relative;
            display: inline-block;
            margin-bottom: 20px;
            margin-right: 11%;
        }

        .dropdown button {
            padding: 8px 16px;
            background-color: #0066cc;
            color: white;
            border: none;
            cursor: pointer;
            font-size: 14px;
            text-align: center;
            width: 150px;
        }

        .dropdown-content {
            display: none;
            position: absolute;
            background-color: #f9f9f9;
            min-width: 160px;
            box-shadow: 0px 8px 16px 0px rgba(0, 0, 0, 0.2);
            z-index: 1;
            border-radius: 4px;
        }

        .dropdown-content label {
            display: flex;
            align-items: center;
            padding: 8px 16px;
            cursor: pointer;
        }

        .dropdown-content input[type="checkbox"] {
            margin-right: 8px;
            accent-color: #4CAF50;
        }

        .dropdown-content label:hover {
            background-color: #ddd;
        }

        .table-container {
            max-width: 100%;
            overflow-y: hidden;
            overflow-x: auto;
            margin: 0 auto;
            border-radius: 5px;
            background-color: rgba(255, 255, 255, 0.1);
        }

        .status-circle.approved i {
            color: #4caf50;
        }

        .status-circle.rejected i {
            color: #f44336;
        }

        .status-circle.pending i {
            color: #808080;
        }

        .status-text {
            color: black;
        }

        .status-circle {
            display: flex;
            align-items: center;
        }

        .status-text {
            margin-left: 5px;
        }

       .sort-arrow {
        margin-left: 5px;
        font-size: 12px;
        color: #333;
        transition: transform 0.3s ease;
        }
        
        .asc::after {
            content: '\f062'; /* FontAwesome arrow-up */
            font-family: 'Font Awesome 5 Free';
            font-weight: 900;
            color: #333;
        }
        
        .desc::after {
            content: '\f063'; /* FontAwesome arrow-down */
            font-family: 'Font Awesome 5 Free';
            font-weight: 900;
            color: #333;
        }


        /* Style for dropdown when visible */
        .dropdown-content.show {
            display: block;
        }
        
         @media print {
           body * {
                visibility: hidden;
            }
            table, table * {
                visibility: visible;
            }
            table {
                position: relative;
                width: 100%;
                left: 0;
                top: 0;
            }
            
              /* Hide the action column during printing */
            .action-column,
            .print-hide {
                display: none;
            }
        }
    </style>
</head>
<body>
    <h2>Pending Approval</h2>
    <br>

    <!-- Search and Column Toggle Container -->
    <div class="search-container">
        <!-- Search Bar -->
        <input type="text" id="globalSearch" placeholder="Search in table..." onkeyup="filterTable()">
        
        <div class="dropdown">
            <button onclick="toggleDropdown()">Toggle Columns</button>
            <div id="myDropdown" class="dropdown-content">
                <label><input type="checkbox" checked onchange="toggleColumn(0)"> ID</label>
                <label><input type="checkbox" checked onchange="toggleColumn(1)"> Host Name</label>
                <label><input type="checkbox" checked onchange="toggleColumn(2)"> Email</label>
                <label><input type="checkbox" checked onchange="toggleColumn(3)"> Department</label>
                <label><input type="checkbox" checked onchange="toggleColumn(4)"> Approver</label>
                <label><input type="checkbox" checked onchange="toggleColumn(5)"> Status</label>
                <label><input type="checkbox" checked onchange="toggleColumn(6)"> Action</label>
            </div>
        </div>
    </div>

    <div class="table-container">
        <table id="inquiryTable">
            <thead>
                <tr>
                    <th onclick="sortTable(0)">ID <span class="sort-arrow"></span></th>
                    <th onclick="sortTable(1)">Host Name <span class="sort-arrow"></span></th>
                    <th onclick="sortTable(2)">Email <span class="sort-arrow"></span></th>
                    <th onclick="sortTable(3)">Department <span class="sort-arrow"></span></th>
                    <th onclick="sortTable(4)">Approver <span class="sort-arrow"></span></th>
                    <th onclick="sortTable(5)">Status <span class="sort-arrow"></span></th>
                    <th class="print-hide">Action</th>
                </tr>
            </thead>
            <tbody>
                <?php
                $number = 1;
                while ($fetch = mysqli_fetch_array($result)): ?>
                    <tr>
                        <td><?php echo $number++; ?></td>
                        <td><?php echo htmlspecialchars($fetch['Host']); ?></td>
                        <td><?php echo htmlspecialchars($fetch['General_Email']); ?></td>
                        <td><?php echo htmlspecialchars($fetch['Department']); ?></td>
                        <td><?php echo htmlspecialchars($fetch['Approver']); ?></td>
                        <td>
                            <?php
                            if ($fetch['Status'] === 'approved') {
                                echo '<div class="status-circle approved">
                                          <i class="fas fa-check-circle"></i>
                                          <span class="status-text">Approved</span>
                                      </div>';
                            } elseif ($fetch['Status'] === 'rejected') {
                                echo '<div class="status-circle rejected">
                                          <i class="fas fa-times-circle"></i>
                                          <span class="status-text">Rejected</span>
                                      </div>';
                            } elseif ($fetch['Status'] === 'pending') {
                                echo '<div class="status-circle pending">
                                          <i class="fas fa-clock"></i>
                                          <span class="status-text">Pending</span>
                                      </div>';
                            } else {
                                echo '<span>' . htmlspecialchars($fetch['Status']) . '</span>';
                            }
                            ?>
                        </td>
                        <td class="action-column print-hide">
                            <div style="display: flex; justify-content: center; gap: 10px;">
                                <select id="actionDropdown<?php echo htmlspecialchars($fetch['ID']); ?>" onchange="performVisitorAction(<?php echo htmlspecialchars($fetch['ID']); ?>, this)">
                                    <option value="">Action</option>
                                    <option value="view">View</option>
                                    <?php if ($fetch['Status'] === 'pending'): ?>
                                        <option value="approve">Approve</option>
                                        <option value="reject">Reject</option>
                                    <?php endif; ?>
                                </select>
                            </div>
                        </td>
                    </tr>
                <?php endwhile; ?>
            </tbody>
        </table>
    </div>
    
     <div>
        <button type="button" id="printButton" onclick="print12()">Print</button>
    </div>

    <script>
        let currentSortColumn = -1;
        let currentSortDirection = 'asc';

        // Toggle column visibility
        function toggleColumn(index) {
            const table = document.getElementById('inquiryTable');
            const rows = table.getElementsByTagName('tr');

            for (let i = 0; i < rows.length; i++) {
                const cell = rows[i].getElementsByTagName('td')[index] || rows[i].getElementsByTagName('th')[index];
                if (cell) {
                    cell.style.display = cell.style.display === 'none' ? '' : 'none';
                }
            }
        }
        
        
         // Print table
        function print12() {
            window.print();
        }

        // Toggle the dropdown visibility
        function toggleDropdown() {
            const dropdown = document.getElementById("myDropdown");
            dropdown.classList.toggle("show");
        }

        // Close the dropdown if the user clicks outside of it
        window.onclick = function(event) {
            if (!event.target.matches('.dropdown button')) {
                const dropdowns = document.getElementsByClassName("dropdown-content");
                for (let i = 0; i < dropdowns.length; i++) {
                    const openDropdown = dropdowns[i];
                    if (openDropdown.classList.contains('show')) {
                        openDropdown.classList.remove('show');
                    }
                }
            }
        }

        function sortTable(columnIndex) {
    const table = document.getElementById("inquiryTable");
    const rows = Array.from(table.rows).slice(1); // skip header row
    let sortedRows;

    // Toggle sort direction and sort
    if (currentSortColumn === columnIndex) {
        currentSortDirection = currentSortDirection === 'asc' ? 'desc' : 'asc';
    } else {
        currentSortColumn = columnIndex;
        currentSortDirection = 'asc';
    }

    sortedRows = rows.sort((rowA, rowB) => {
        const cellA = rowA.cells[columnIndex].textContent.trim();
        const cellB = rowB.cells[columnIndex].textContent.trim();

        if (columnIndex === 5) { // Status column: handle special sorting
            const statusOrder = { 'pending': 0, 'approved': 1, 'rejected': 2 };
            return currentSortDirection === 'asc'
                ? statusOrder[cellA] - statusOrder[cellB]
                : statusOrder[cellB] - statusOrder[cellA];
        }

        return currentSortDirection === 'asc'
            ? cellA.localeCompare(cellB)
            : cellB.localeCompare(cellA);
    });

    // Rebuild the table with sorted rows
    table.tBodies[0].append(...sortedRows);

    // Update sort arrows for each column
    updateSortArrows(columnIndex);
}

function updateSortArrows(columnIndex) {
    const headers = document.querySelectorAll('th');
    
    // Reset all arrows
    headers.forEach((header, index) => {
        const arrow = header.querySelector('.sort-arrow');
        if (arrow) {
            arrow.classList.remove('asc', 'desc');
        }
    });

    // Add the correct arrow class for the sorted column
    const sortedHeader = headers[columnIndex];
    const arrow = sortedHeader.querySelector('.sort-arrow');

    if (arrow) {
        arrow.classList.add(currentSortDirection); // Add 'asc' or 'desc'
    }
}

        
        // Filter the table rows based on the search input
        function filterTable() {
            const input = document.getElementById("globalSearch");
            const filter = input.value.toUpperCase();
            const table = document.getElementById("inquiryTable");
            const tr = table.getElementsByTagName("tr");

            for (let i = 1; i < tr.length; i++) {
                const tds = tr[i].getElementsByTagName("td");
                let found = false;

                for (let j = 0; j < tds.length; j++) {
                    if (tds[j] && tds[j].textContent.toUpperCase().indexOf(filter) > -1) {
                        found = true;
                        break;
                    }
                }

                tr[i].style.display = found ? "" : "none";
            }
        }

       // Perform visitor action
        function performVisitorAction(id, selectElement) {
        const action = selectElement.value;
        if (!action) return; // No action selected, exit the function
    
        // Confirmation message for approve/reject
        let confirmationMessage = '';
        if (action === 'approve') {
            confirmationMessage = 'Are you sure you want to approve this request?';
        } else if (action === 'reject') {
            confirmationMessage = 'Are you sure you want to reject this request?';
        }
    
        // Handle "View" action (no confirmation needed)
        if (action === 'view') {
            window.location.href = `vis_display_detail_0.php?id=${id}`;
        } else if (confirmationMessage && confirm(confirmationMessage)) {
            // For "approve" and "reject", ask for confirmation before proceeding
            window.location.href = `visitor_action.php?action=${action}&id=${id}`;
        }
    
        // Reset the dropdown value after action
        selectElement.value = "";
    }

    </script>

</body>
</html>

