<?php
// admin_scan.php

// Start the session
session_start();

// Check if the user is logged in as an admin
if (!isset($_SESSION['user_role']) || $_SESSION['user_role'] !== 'admin') {
    header("Location: login.php");
    exit();
}

?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin QR Code Scanner</title>
    <style>
        #video {
            width: 100%;
            max-width: 600px;
            height: auto;
            border: 2px solid #000;
        }
        #canvas {
            display: none; /* Hide canvas initially */
        }
        #results {
            margin-top: 10px;
            font-weight: bold;
        }
        .btn {
            margin: 5px;
            padding: 10px 15px;
            background-color: #28a745;
            color: white;
            border: none;
            border-radius: 5px;
            cursor: pointer;
        }
    </style>
</head>
<body>

<div id="logo">
    <a href="/admin/dashboard.php" style="text-decoration: none; color: inherit;">
        <h1>Admin QR Code Scanner</h1>
    </a>
</div>

<video id="video" autoplay></video>
<button type="button" id="snap" class="btn">Scan</button>
<button type="button" onClick="vidOn()" class="btn">Start</button>
<button type="button" onClick="vidOff()" class="btn">Stop</button>

<canvas id="canvas" width="600" height="480"></canvas>
<div id="results"></div>

<script>
    var video = document.getElementById('video');
    var canvas = document.getElementById('canvas');
    var context = canvas.getContext('2d');

    // Get access to the camera
    function vidOn() {
        if (navigator.mediaDevices && navigator.mediaDevices.getUserMedia) {
            navigator.mediaDevices.getUserMedia({ video: true })
                .then(function(stream) {
                    video.srcObject = stream;
                    video.play();
                })
                .catch(function(err) {
                    console.error("Error accessing camera: " + err);
                });
        }
    }

    function vidOff() {
        video.pause();
        video.srcObject.getTracks().forEach(track => track.stop()); // Stop all video tracks
        video.srcObject = null;
    }

    // Capture frame and scan for QR code
    document.getElementById("snap").addEventListener("click", function() {
        context.drawImage(video, 0, 0, canvas.width, canvas.height);
        canvas.toBlob(function(blob) {
            var formData = new FormData();
            formData.append("file", blob); // Append the captured image

            // Send the image to the QR code API
            fetch('http://api.qrserver.com/v1/read-qr-code/', {
                method: 'POST',
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                if (data && data[0].data) {
                    // Process the QR code data (e.g., display or redirect)
                    document.getElementById('results').innerText = "QR Code Data: " + data[0].data;
                } else {
                    document.getElementById('results').innerText = "No QR code found. Try again.";
                }
            })
            .catch(error => {
                console.error("Error reading QR code: ", error);
                document.getElementById('results').innerText = "Error reading QR code.";
            });
        }, 'image/jpeg'); // Change to the desired image format
    });
</script>

</body>
</html>
