<?php
include('dbconn.php');

// Query to fetch department data and staff count
$sql = "SELECT department.*, 
               (SELECT COUNT(*) FROM login_user WHERE login_user.department_name = department.department_name) AS staff_count 
        FROM department";
$query = mysqli_query($db, $sql);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Departments</title>
    <style>
        body {
            background-color: #f4f4f9;
            margin: 0;
            padding: 0;
            text-align: center;
        }

        .container {
            width: 80%;
            margin: 0 auto;
            font-family: 'Arial', sans-serif;
        }

        /* Search Bar and Column Toggle Container */
        .search-container {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
        }

        #globalSearch {
            padding: 8px;
            width: 82%;
            margin-right: 10px;
            border: 1px solid #333;
            border-radius: 5px;
            font-size: 14px;
        }
        
        #globalSearch:focus {
            border-color: #0056b3;
        }

        /* Table Styling */
        table {
            width: 100%;
            border-collapse: collapse;
            margin: 20px 0;
            border: 2px solid grey;
        }

        td, th {
            text-align: center;
            padding: 10px;
            font-size: 12px;
            border: 1px solid #ddd;
        }

        th {
            background-color: #f2f2f2;
            color: #333;
            font-weight: bold;
            cursor: pointer;
        }

        tr:nth-child(even) {
            background-color: #f9f9f9;
            color: #333;
        }
        
        tr:nth-child(odd) {
            background-color: #fff;
            color: #333;
        }

        tr:hover {
            background-color: #f1f1f1;
        }

        /* Sort icon styles */
        .sort-icon {
            display: inline-block;
            width: 0;
            height: 0;
            border-left: 4px solid transparent;
            border-right: 4px solid transparent;
            margin-left: 5px;
            vertical-align: middle;
        }

        /* Upward arrow (ascending) */
        .sort-icon.asc {
            border-bottom: 6px solid #4CAF50;
        }

        /* Downward arrow (descending) */
        .sort-icon.desc {
            border-top: 6px solid #4CAF50;
        }

        /* Button Styles */
        button {
            padding: 10px 20px;
            background-color: #0066cc;
            color: white;
            border: none;
            cursor: pointer;
            border-radius: 4px;
            font-size: 16px;
            margin: 5px;
        }

        button:hover {
            background-color: #0056b3;
        }

        /* Dropdown Button */
        .dropdown button {
            padding: 8px 16px;
            background-color: #0066cc;
            color: white;
            border: none;
            cursor: pointer;
            font-size: 14px;
            text-align: center;
            width: 150px;
        }

        /* Dropdown content (hidden by default) */
        .dropdown-content {
            display: none;
            position: absolute;
            background-color: #f9f9f9;
            min-width: 160px;
            box-shadow: 0px 8px 16px 0px rgba(0, 0, 0, 0.2);
            z-index: 1;
            border-radius: 4px;
        }

        .dropdown-content label {
            display: flex;
            align-items: center;
            padding: 8px 16px;
            cursor: pointer;
        }

        .dropdown-content input[type="checkbox"] {
            margin-right: 8px;
            accent-color: #4CAF50;
        }

        .dropdown-content label:hover {
            background-color: #ddd;
        }

        .show {
            display: block;
        }
        
      /* Print layout */
        @media print {
           body * {
                visibility: hidden;
            }
            table, table * {
                visibility: visible;
            }
            table {
                position: relative;
                width: 100%;
                left: 0;
                top: 0;
            }
        }

    </style>
</head>
<body>

<div class="container">
    <!-- Table Header -->
    <h2>Departments and Staff</h2>
    <br>

    <!-- Search and Column Toggle Container -->
    <div class="search-container">
        <!-- Search Bar -->
        <input type="text" id="globalSearch" placeholder="Search in table..." onkeyup="filterTable()">
        
        <!-- Column Toggle Dropdown -->
        <div class="dropdown">
            <button onclick="toggleDropdown()">Toggle Columns</button>
            <div id="myDropdown" class="dropdown-content">
                <label><input type="checkbox" checked onchange="toggleColumn(0)"> No.</label>
                <label><input type="checkbox" checked onchange="toggleColumn(1)"> Department Name</label>
                <label><input type="checkbox" checked onchange="toggleColumn(2)"> Number of Staff</label>
            </div>
        </div>
    </div>

    <!-- Department Table -->
    <table id="inquiryTable">
        <thead>
            <tr>
                <th onclick="sortTable(0)">No. <span id="sort-icon-0" class="sort-icon"></span></th>
                <th onclick="sortTable(1)">Department Name <span id="sort-icon-1" class="sort-icon"></span></th>
                <th onclick="sortTable(2)">Number of Staff <span id="sort-icon-2" class="sort-icon"></span></th>
            </tr>
        </thead>
        <tbody>
            <?php
            $count = 1;
            $totalStaff = 0;

            while ($fetch = mysqli_fetch_array($query)) {
                echo "<tr>";
                echo "<td>" . $count++ . "</td>";
                echo "<td>" . htmlspecialchars($fetch['department_name']) . "</td>";
                echo "<td>" . $fetch['staff_count'] . "</td>";
                $totalStaff += $fetch['staff_count'];
                echo "</tr>";
            }
            ?>

            <!-- Total Staff Row -->
            <tr>
                <td colspan="2" style="font-weight: bold;">Total Staff:</td>
                <td style="font-weight: bold;"><?php echo $totalStaff; ?></td>
            </tr>
        </tbody>
    </table>

    <!-- Action Buttons -->
    <div>
        <button type="button" id="createButton" onclick="createVisitor()">Add</button>
        <button type="button" id="printButton" onclick="print12()">Print</button>
    </div>
</div>

<script>
    let sortDirection = { 0: 'asc', 1: 'asc', 2: 'asc' };

    function sortTable(columnIndex) {
        const table = document.getElementById("inquiryTable");
        const rows = Array.from(table.getElementsByTagName("tr")).slice(1); // Get all rows except the header row
        const arrow = document.getElementById(`sort-icon-${columnIndex}`);
        const direction = sortDirection[columnIndex];

        rows.sort((rowA, rowB) => {
            const cellA = rowA.cells[columnIndex].innerText.toLowerCase();
            const cellB = rowB.cells[columnIndex].innerText.toLowerCase();

            if (direction === 'asc') {
                return cellA > cellB ? 1 : cellA < cellB ? -1 : 0;
            } else {
                return cellA < cellB ? 1 : cellA > cellB ? -1 : 0;
            }
        });

        // Reattach rows in sorted order
        rows.forEach(row => table.appendChild(row));

        // Toggle sort direction and update the arrow
        sortDirection[columnIndex] = direction === 'asc' ? 'desc' : 'asc';
        arrow.classList.toggle('asc', direction === 'asc');
        arrow.classList.toggle('desc', direction === 'desc');
    }

    // Function to search the table
    function filterTable() {
        var input, filter, table, tr, td, i, j, txtValue;
        input = document.getElementById("globalSearch");
        filter = input.value.toUpperCase();
        table = document.getElementById("inquiryTable");
        tr = table.getElementsByTagName("tr");

        for (i = 1; i < tr.length; i++) {
            tr[i].style.display = "none"; 
            for (j = 0; j < tr[i].cells.length; j++) {
                td = tr[i].getElementsByTagName("td")[j];
                if (td) {
                    txtValue = td.textContent || td.innerText;
                    if (txtValue.toUpperCase().indexOf(filter) > -1) {
                        tr[i].style.display = ""; 
                        break; 
                    }
                }
            }
        }
    }

    // Function to toggle the column visibility
    function toggleColumn(index) {
        const table = document.getElementById("inquiryTable");
        const rows = table.getElementsByTagName("tr");

        for (let i = 0; i < rows.length; i++) {
            const cells = rows[i].getElementsByTagName(i === 0 ? "th" : "td"); // Handle header and data rows
            if (cells[index]) {
                cells[index].style.display = cells[index].style.display === "none" ? "" : "none";
            }
        }
    }
    
      // Print table
    function print12() {
        window.print();
    }

    // Show or hide dropdown content
    function toggleDropdown() {
        document.getElementById("myDropdown").classList.toggle("show");
    }

    // Close the dropdown if clicked outside
    window.onclick = function(event) {
        if (!event.target.matches('.dropdown button')) {
            var dropdowns = document.getElementsByClassName("dropdown-content");
            for (var i = 0; i < dropdowns.length; i++) {
                var openDropdown = dropdowns[i];
                if (openDropdown.classList.contains('show')) {
                    openDropdown.classList.remove('show');
                }
            }
        }
    };

    // Create a new visitor (redirect to a page)
    function createVisitor() {
        window.location.href = '/vms/php/department_0.php';
    }

</script>

</body>
</html>
