<?php
include('dbconn.php');

// Check if the user is logged in
if (!isset($_SESSION['user_id'])) {
    echo "<script>alert('Please log in first.'); location.href='../index.html';</script>";
    exit();
}

// Fetch the logged-in user ID and role
$userId = $_SESSION['user_id'];
$role_name = $_SESSION['role']; // Ensure you have the user role in session

// Determine SQL query based on user role
if ($role_name == 'Admin' || $role_name == 'Guard') {
    // Admin can see all users
    $sql = "SELECT ID, General_Email, Department, Host, created_at FROM visitors";
} else {
    // SQL query to fetch visitor details based on approver ID
    $sql = "SELECT ID, General_Email, Department, Host, created_at FROM visitors WHERE Approver = ?";
    $stmt = $db->prepare($sql);
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $result = $stmt->get_result();
}

// Execute the SQL query for admin
if ($role_name == 'Admin' || $role_name == 'Guard') {
    $result = $db->query($sql);
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Visitor Details</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style>
        body {
            text-align: center;
            background-size: cover;
            background-repeat: no-repeat;
            color: white;
        }
        table {
            border-collapse: collapse;
            margin: auto;
            width: 80%;
            border: 2px solid grey;
        }
        
        td, th {
            text-align: center;
            padding: 10px;
            font-size: 12px;
            border: 1px solid #ddd;
        }

        th {
            background-color: #f2f2f2;
            color: #333;
            font-weight: bold;
            cursor: pointer;
        }

        tr:nth-child(even) {
            background-color: #f9f9f9;
            color: #333;
        }

        tr:nth-child(odd) {
            background-color: #fff;
            color: #333;
        }

        tr:hover {
            background-color: #f1f1f1;
        }

        /* Search Bar and Column Toggle Container */
        .search-container {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
            margin-left: 10%;
        }

        #globalSearch {
            padding: 8px;
            width: 71%;
            margin-right: 10px;
            border: 1px solid #333;
            border-radius: 5px;
            font-size: 14px;
        }

        #globalSearch:focus {
            border-color: #0056b3;
        }
        
        
        
        #printButton {
            padding: 8px 16px;
            background-color: #0066cc;
            color: white;
            border: none;
            cursor: pointer;
            border-radius: 5px;
            font-size: 16px;
            margin: 20px;
        }


        .filter-container {
            margin: 20px;
        }

        .dropdown {
            position: relative;
            display: inline-block;
            margin-bottom: 5px;
            margin-right: 11%;
        }

        .dropdown button {
            padding: 8px 16px;
            background-color: #0066cc;
            color: white;
            border: none;
            cursor: pointer;
            font-size: 14px;
            text-align: center;
            width: 150px;
        }

        .dropdown-content {
            display: none;
            position: absolute;
            background-color: #f9f9f9;
            min-width: 160px;
            box-shadow: 0px 8px 16px 0px rgba(0, 0, 0, 0.2);
            z-index: 1;
            border-radius: 4px;
        }

        .dropdown-content label {
            display: flex;
            align-items: center;
            padding: 8px 16px;
            cursor: pointer;
        }

        .dropdown-content input[type="checkbox"] {
            margin-right: 8px;
            accent-color: #4CAF50;
        }

        .dropdown-content label:hover {
            background-color: #ddd;
        }

        .table-container {
            max-width: 100%;
            overflow-y: hidden;
            overflow-x: auto;
            margin: 0 auto;
            border-radius: 5px;
            background-color: rgba(255, 255, 255, 0.1);
        }

        .status-circle.approved i {
            color: #4caf50;
        }

        .status-circle.rejected i {
            color: #f44336;
        }

        .status-circle.pending i {
            color: #808080;
        }

        .status-text {
            color: black;
        }

        .status-circle {
            display: flex;
            align-items: center;
        }

        .status-text {
            margin-left: 5px;
        }

        .sort-arrow {
            margin-left: 5px;
            font-size: 12px;
            color: #333;
            transition: transform 0.3s ease;
        }
        
        .asc::after {
            content: '\f062'; /* FontAwesome arrow-up */
            font-family: 'Font Awesome 5 Free';
            font-weight: 900;
            color: #333;
        }
        
        .desc::after {
            content: '\f063'; /* FontAwesome arrow-down */
            font-family: 'Font Awesome 5 Free';
            font-weight: 900;
            color: #333;
        }

        /* Style for dropdown when visible */
        .dropdown-content.show {
            display: block;
        }

        /* Hide everything except the table when printing */
        @media print {
            body * {
                visibility: hidden;
            }
            #inquiryTable, #inquiryTable * {
                visibility: visible;
            }
            #inquiryTable td:nth-child(6), /* Hide the Action column */
            #inquiryTable th:nth-child(6) {
                display: none;
            }
            #printButton {
                visibility: hidden;
            }
        }
    </style>
</head>
<body>
    <h2>Pre-Registration Visitor Details</h2>
    <br>

    <!-- Search and Column Toggle Container -->
    <div class="search-container">
        <!-- Search Bar -->
        <input type="text" id="globalSearch" placeholder="Search in table..." onkeyup="filterTable()">
        
        <div class="dropdown">
            <button onclick="toggleDropdown()">Toggle Columns</button>
            <div id="myDropdown" class="dropdown-content">
                <label><input type="checkbox" checked onchange="toggleColumn(0)"> ID</label>
                <label><input type="checkbox" checked onchange="toggleColumn(1)"> Host Name</label>
                <label><input type="checkbox" checked onchange="toggleColumn(2)"> Email</label>
                <label><input type="checkbox" checked onchange="toggleColumn(3)"> Department</label>
                <label><input type="checkbox" checked onchange="toggleColumn(4)"> Created At</label>
                <label><input type="checkbox" checked onchange="toggleColumn(5)"> Action</label>
            </div>
        </div>
    </div>

    <div class="table-container">
        <table id="inquiryTable">
            <thead>
                <tr>
                    <th onclick="sortTable(0)">ID <span class="sort-arrow"></span></th>
                    <th onclick="sortTable(1)">Host Name <span class="sort-arrow"></span></th>
                    <th onclick="sortTable(2)">Email <span class="sort-arrow"></span></th>
                    <th onclick="sortTable(3)">Department <span class="sort-arrow"></span></th>
                    <th onclick="sortTable(4)">Created At <span class="sort-arrow"></span></th>
                    <th>Action</th>
                </tr>
            </thead>
            <tbody>
                <?php
                $number = 1;
                while ($fetch = mysqli_fetch_array($result)): ?>
                    <tr>
                        <td><?php echo $number++; ?></td>
                        <td><?php echo htmlspecialchars($fetch['Host']); ?></td>
                        <td><?php echo htmlspecialchars($fetch['General_Email']); ?></td>
                        <td><?php echo htmlspecialchars($fetch['Department']); ?></td>
                        <td><?php echo htmlspecialchars($fetch['created_at']); ?></td>
                        <td>
                            <div style="display: flex; justify-content: center; gap: 10px;">
                                <select id="actionDropdown<?php echo htmlspecialchars($fetch['ID']); ?>" onchange="performVisitorAction(<?php echo htmlspecialchars($fetch['ID']); ?>, this)">
                                    <option value="">Action</option>
                                    <option value="view">View</option>
                                </select>
                            </div>
                        </td>
                    </tr>
                <?php endwhile; ?>
            </tbody>
        </table>
    </div>

    <!-- Print Button -->
    <button id="printButton" onclick="print12()">Print</button>

    <script>
        let currentSortColumn = -1;
        let currentSortDirection = 'asc';

        // Function to print only the table
        function print12() {
            window.print();
        }

        function filterTable() {
            const input = document.getElementById("globalSearch");
            const filter = input.value.toLowerCase();
            const table = document.getElementById("inquiryTable");
            const rows = table.getElementsByTagName("tr");

            for (let i = 1; i < rows.length; i++) {
                let row = rows[i];
                let cells = row.getElementsByTagName("td");
                let match = false;

                for (let j = 0; j < cells.length; j++) {
                    if (cells[j].textContent.toLowerCase().indexOf(filter) > -1) {
                        match = true;
                        break;
                    }
                }

                if (match) {
                    row.style.display = "";
                } else {
                    row.style.display = "none";
                }
            }
        }

        // Function to sort the table
        function sortTable(n) {
            const table = document.getElementById("inquiryTable");
            const rows = table.rows;
            let switching = true;

            while (switching) {
                switching = false;
                const rowsArray = Array.from(rows).slice(1);
                for (let i = 0; i < rowsArray.length - 1; i++) {
                    let x = rowsArray[i].getElementsByTagName("TD")[n];
                    let y = rowsArray[i + 1].getElementsByTagName("TD")[n];
                    let shouldSwitch = false;

                    if (currentSortDirection === 'asc') {
                        if (x.innerHTML.toLowerCase() > y.innerHTML.toLowerCase()) {
                            shouldSwitch = true;
                            break;
                        }
                    } else {
                        if (x.innerHTML.toLowerCase() < y.innerHTML.toLowerCase()) {
                            shouldSwitch = true;
                            break;
                        }
                    }

                    if (shouldSwitch) {
                        rowsArray[i].parentNode.insertBefore(rowsArray[i + 1], rowsArray[i]);
                        switching = true;
                    }
                }
            }

            currentSortDirection = (currentSortDirection === 'asc') ? 'desc' : 'asc';
        }

        function toggleColumn(index) {
            const table = document.getElementById('inquiryTable');
            const th = table.getElementsByTagName('th')[index];
            const tds = table.getElementsByTagName('td');
            const isVisible = th.style.display !== 'none';

            if (isVisible) {
                th.style.display = 'none';
                for (let i = 0; i < tds.length; i++) {
                    if (i % table.rows[0].cells.length === index) {
                        tds[i].style.display = 'none';
                    }
                }
            } else {
                th.style.display = '';
                for (let i = 0; i < tds.length; i++) {
                    if (i % table.rows[0].cells.length === index) {
                        tds[i].style.display = '';
                    }
                }
            }
        }

        // Dropdown toggle for column visibility
        function toggleDropdown() {
            const dropdown = document.getElementById("myDropdown");
            dropdown.classList.toggle("show");
        }
        
        // Perform visitor action
        function performVisitorAction(id, selectElement) {
            const action = selectElement.value;
            if (!action) return; // No action selected, exit the function
        
            // Handle "View" action (no confirmation needed)
            if (action === 'view') {
                window.location.href = `vis_display_detail_0.php?id=${id}`;
            }
        
            // Reset the dropdown value after action
            selectElement.value = "";
        }
    </script>
</body>
</html>
