<!doctype html>
<html lang="en">
<head>
    <title>Visitor Report</title>
    <script type="text/javascript">
        function print1() {
            var w = document.getElementById('p1');
            var w1 = document.getElementById('p2');
            w.style.display = 'none';
            w1.style.display = 'none';
            window.print();
            w.style.display = 'block';
            w1.style.display = 'block';
        }
    </script>
    <style>
        body {
            text-align: center;
            background-color: #f2f2f2;
            font-family: 'Poppins', sans-serif;
        }

        table {
            border-collapse: collapse;
            width: 80%;
            margin: 0 auto;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            background-color: #ffffff;
        }

        th, td {
            height: 60px;
            color: black;
            border: 1px solid #ddd;
            padding: 10px;
        }

        th {
            background-color: #da291c;
            color: white;
            font-family: verdana;
            font-size: 18px;
        }

        .custom-btn {
            display: inline-block;
            font-size: 16px;
            font-weight: bold;
            padding: 10px 20px;
            border-radius: 8px;
            border: 2px solid #da291c;
            background-color: #cf0000;
            color: white;
            cursor: pointer;
            transition: all 0.3s ease;
            width: 150px;
            margin: 10px;
        }

        .custom-btn:hover {
            background-color: #c0392b;
            box-shadow: 0 6px 15px rgba(0, 0, 0, 0.3);
        }

        .button-container {
            margin-top: 20px;
            display: flex;
            justify-content: center;
        }

        @media print {
            body {
                background-color: white;
                -webkit-print-color-adjust: exact;
            }

            .button-container {
                display: none;
            }

            table {
                width: 100%;
            }

            th, td {
                font-size: 14px;
            }
        }

        a {
            text-decoration: none;
            color: inherit;
        }
    </style>
</head>
<body>

<div id="header">
    <table id="headerTable">
        <tr>
            <td style="text-align: center; width: 80px;">
                <img src="../images/logo.jpeg" alt="UMEDIC Logo" height="200" width="200">
            </td>
            <td style="color: black; font-family: Arial, sans-serif; text-align: left;">
            <h3>UMEDIC GROUP BERHAD (1415647-D)</h3>
            <h3>UMEDIC HEALTHCARE SDN BHD (598175-W)</h3>
            <h3>UWHM SDN BHD (961995-K)</h3>
            <p>PMT 790, Jalan Cassia Selatan 5/2, Taman Perindustrian Batu Kawan,<br>
            14110 Bandar Cassia, Pulau Pinang, Malaysia.<br>
            T (+6) 04-589 9676 (Ext: 205) | F (+6) 04-589 9677<br>
            <a href="http://www.umedic.com.my" style="color: skyblue;">www.umedic.com.my</a></p>
        </td>

        </tr>
    </table>
</div>

<br>
<?php
include('dbconn.php'); // Include the database connection file

// Get the date range from POST data
$from = $_POST['from'];
$to = $_POST['to'];

// Validate if the date range exists
if (empty($from) || empty($to)) {
    die("Invalid date range.");
}

// Adjust the 'to' date to include the full day by adding 1 day
$to = date('Y-m-d', strtotime($to . ' +1 day'));

// SQL query to fetch data from visitor_details table
$query = "
    SELECT vd.ID, vd.Visitor_ID, vd.Name, vd.Email, vd.Arrive, vd.Leave_Time, vd.created_date
    FROM visitor_details vd
    WHERE vd.created_date BETWEEN ? AND ?
";

// Prepare the SQL statement
$stmt = $db->prepare($query);
if ($stmt === false) {
    die('Error preparing the query: ' . $db->error);
}

// Bind the parameters to the SQL query
$stmt->bind_param('ss', $from, $to);

// Execute the query
$stmt->execute();

// Get the result from the query
$result = $stmt->get_result();

// Check if any rows are returned
if ($result->num_rows === 0) {
    echo "No records found for the given date range.";
} else {
    // Display the results in a table
    echo "<table class='new'>";
    echo "<tr>";
    echo "<th>No</th>";
    echo "<th>Name</th>";
    echo "<th>Email</th>";
    echo "<th>Arrive</th>";
    echo "<th>Leave Time</th>";
    echo "<th>Created Date</th>";
    echo "<th>Duration</th>";  // Added Duration column
    echo "</tr>";

    $counter = 1;
    while ($row = $result->fetch_assoc()) {
        // Calculate the duration
        $arrive = new DateTime($row['Arrive']);
        $leave = new DateTime($row['Leave_Time']);
        $duration = $arrive->diff($leave);
        $durationStr = $duration->format('%h hours %i minutes'); // Format the duration as hours and minutes

        echo "<tr>";
        echo "<td>{$counter}</td>";
        echo "<td>{$row['Name']}</td>";
        echo "<td>{$row['Email']}</td>";
        echo "<td>{$row['Arrive']}</td>";
        echo "<td>{$row['Leave_Time']}</td>";
        echo "<td>{$row['created_date']}</td>";
        echo "<td>{$durationStr}</td>";  // Display the calculated duration
        echo "</tr>";
        $counter++; // Increment the counter
    }
    echo "</table>";
}

// Close the statement and database connection
$stmt->close();
$db->close();
?>

<br><br>

<!-- Buttons for printing and going back -->
<div class="button-container">
    <input type="button" id="p1" class="custom-btn" value="Print" onclick="print1()">
    <a href="../admin_dashboard.php">
        <input type="button" id="p2" class="custom-btn" value="Back">
    </a>
</div>

</body>
</html>
