<?php
include('dbconn.php');

// Fetch the logged-in user ID and role
$userId = $_SESSION['user_id'];
$role_name = $_SESSION['role']; // Ensure you have the user role in session

// Prepare SQL query based on user role
if ($role_name == 'Admin' || $role_name == 'Guard') {
    // Admin and Guard can see both pre-registered visitors and walk-in visitors
    $sql = "SELECT v.ID, v.Department, v.Host, v.Approver, 
                   vd.Name, vd.Email, vd.Phone, vd.Arrive, vd.Leave_Time,
                   CASE 
                       WHEN vd.Arrive IS NULL AND vd.Leave_Time IS NULL THEN 'pending'
                       WHEN vd.Arrive IS NOT NULL AND vd.Leave_Time IS NULL THEN 'arrived'
                       WHEN vd.Leave_Time IS NOT NULL THEN 'left'
                   END AS status 
            FROM visitors v 
            LEFT JOIN visitor_details vd ON v.ID = vd.Visitor_ID";
    $result = $db->query($sql);
    
    // Fetch all walk-in visitors without status filter
    $sql_walkin = "SELECT * FROM walkin_visitors";  // Fetching all walk-ins, no filter
    $result_walkin = $db->query($sql_walkin);

} elseif ($role_name == 'Approver') {
    // Approver can only see pre-registered visitors they approved
    $sql = "SELECT v.ID, v.Department, v.Host, v.Approver, 
                   vd.Name, vd.Email, vd.Phone, vd.Arrive, vd.Leave_Time,
                   CASE 
                       WHEN vd.Arrive IS NULL AND vd.Leave_Time IS NULL THEN 'pending'
                       WHEN vd.Arrive IS NOT NULL AND vd.Leave_Time IS NULL THEN 'arrived'
                       WHEN vd.Leave_Time IS NOT NULL THEN 'left'
                   END AS status 
            FROM visitors v 
            LEFT JOIN visitor_details vd ON v.ID = vd.Visitor_ID
            WHERE v.Approver = ?"; 

    $stmt = $db->prepare($sql);
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    // For approver, no walk-in visitor data is needed, so we skip the walk-in query
    $result_walkin = null;
    
} else {
    die("Unauthorized access");
}

// Handle potential query errors
if (!$result) {
    die("Query failed: " . mysqli_error($db));
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Visitor Details</title>
    <style>
        body {
            font-family: 'Poppins', sans-serif;
            background-color: #eef2f3;
            margin: 0;
            padding: 0;
        }

        .form-container {
            max-width: 900px;
            margin: auto;
        }

        table {
            width: 80%;
            border-collapse: collapse;
            margin-top: 20px;
            border: 2px solid grey;
            margin-left: 107px;
        }

        td, th {
            text-align: left; /* Align text to the left */
            padding: 10px;
            font-size: 12px;
            border: 1px solid #ddd;
        }

        th {
            background-color: #f2f2f2;
            color: #333;
            font-weight: bold;
            cursor: pointer;
        }

        tr:nth-child(even) {
            background-color: #f9f9f9;
            color: #333;
        }

        tr:nth-child(odd) {
            background-color: #fff;
            color: #333;
        }

        tr:hover {
            background-color: #f1f1f1;
        }

        .search-container {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
            padding: 0 20px;
        }

        #globalSearch {
            padding: 8px;
            width: 90%;
            margin-right: 58px;
            border: 1px solid #333;
            border-radius: 5px;
            font-size: 14px;
        }

        #globalSearch:focus {
            border-color: #0056b3;
        }

        .dropdown {
            position: relative;
            display: inline-block;
            width: 21%;
        }

        .dropdown button {
            padding: 8px 16px;
            background-color: #0066cc;
            color: white;
            border: none;
            cursor: pointer;
            font-size: 14px;
        }

        .dropdown-content {
            display: none;
            position: absolute;
            background-color: #f9f9f9;
            min-width: 160px;
            box-shadow: 0px 8px 16px 0px rgba(0, 0, 0, 0.2);
            z-index: 1;
            border-radius: 4px;
        }

        .dropdown-content label {
            display: flex;
            align-items: center;
            padding: 8px 16px;
            cursor: pointer;
        }

        .dropdown-content input[type="checkbox"] {
            margin-right: 8px;
            accent-color: #4CAF50;
        }

        .dropdown-content label:hover {
            background-color: #ddd;
        }

        button {
            background-color: #0066cc;
            color: white;
            border: none;
            border-radius: 5px;
            padding: 10px 20px;
            cursor: pointer;
            font-size: 16px;
        }

        button:hover {
            background-color: #0055a5;
        }
        
           #printButton{
            padding: 10px 20px;
            font-size: 14px;
            border: none;
            background-color: #0066cc;
            color: white;
            border-radius: 5px;
            cursor: pointer;
            margin-top: 20px;
        }
        #printButton:hover {
            background-color: #444;
        }

        .sort-arrow {
            margin-left: 10px;
            font-size: 12px;
        }

        .sort-asc::after {
            content: "▲";
        }

        .sort-desc::after {
            content: "▼";
        }

        /* New styles for the titles */
        h3 {
            font-size: 18px;
            text-align: left;
            margin-left: 85px;
            text-decoration: underline; /* Underline the table titles */
            padding-left: 20px;
        }

     @media print {
    /* Hide everything except the table */
    body * {
        visibility: hidden;
    }
    table, table * {
        visibility: visible;
    }

    /* Ensure h3 titles are visible and styled properly */
    h3 {
        visibility: visible;
        margin-left: -15px;
    }

    table {
            position: relative;
            width: 100%;
            left: 0;
            top: 0;
            margin-left: -10px;
                
            }

    /* Table headers and cells styling */
    th {
        font-weight: bold;
        font-size: 14px;
        padding: 10px;
    }

    td {
        font-size: 12px;
        padding: 8px;
    }

    th, td {
        text-align: left;
        border: 1px solid #ddd;
    }

    /* Hide the action column and other non-essential elements during printing */
    .action-column,
    .print-hide,
    .search-container,
    .dropdown,
    #printButton,
    h2 {
        display: none;
    }


    /* General body settings for print */
    body {
        margin: 20px;
        font-size: 12px;
    }

    /* Row styles for alternate background */
    tr:nth-child(odd) {
        background-color: #f9f9f9;
    }

    tr:nth-child(even) {
        background-color: #ffffff;
    }
}

}


    </style>
</head>
<body>
    
      <h2>Awaiting Arrival</h2>
      <br>

<div class="form-container">
    <div class="search-container">
        <!-- Search Bar -->
        <input type="text" id="globalSearch" placeholder="Search in table..." onkeyup="filterTable()">

        <!-- Dropdown for toggling columns -->
        <div class="dropdown"> 
            <button onclick="toggleDropdown()">Toggle Columns</button>
            <div id="myDropdown" class="dropdown-content">
                <label><input type="checkbox" checked onchange="toggleColumn(0)"> No</label>
                <label><input type="checkbox" checked onchange="toggleColumn(1)"> Name</label>
                <label><input type="checkbox" checked onchange="toggleColumn(2)"> Email</label>
                <label><input type="checkbox" checked onchange="toggleColumn(3)"> Phone</label>
                <label><input type="checkbox" checked onchange="toggleColumn(4)"> Arrival Time</label>
                <label><input type="checkbox" checked onchange="toggleColumn(5)"> Leave Time</label>
                <label><input type="checkbox" checked onchange="toggleColumn(6)"> Status</label>
            </div>
        </div>
    </div>
</div>

<br>

<!-- Pre-registered Visitors -->
<h3 class="print-title">Pre-Registered Visitors</h3>
<table id="preRegisteredTable">
    <thead>
        <tr>
            <th>No</th>
            <th>Visitor Name</th>
            <th>Email</th>
            <th>Phone</th>
            <th>Arrival Time</th>
            <th>Leave Time</th>
            <th>Status</th>
        </tr>
    </thead>
    <tbody>
        <?php 
        $counter = 1;
        while ($row = mysqli_fetch_assoc($result)): ?>
            <tr>
                <td><?php echo $counter++; ?></td>
                <td><?php echo htmlspecialchars($row['Name']); ?></td>
                <td><?php echo htmlspecialchars($row['Email']); ?></td>
                <td><?php echo htmlspecialchars($row['Phone']); ?></td>
                <td><?php echo htmlspecialchars($row['Arrive'] !== null ? $row['Arrive'] : 'N/A'); ?></td>
                <td><?php echo htmlspecialchars($row['Leave_Time'] !== null ? $row['Leave_Time'] : 'N/A'); ?></td>
                <td><?php echo htmlspecialchars($row['status']); ?></td>
            </tr>
        <?php endwhile; ?>
    </tbody>
</table>

<?php if ($role_name == 'Admin' || $role_name == 'Guard'): ?>
    <!-- Walk-in Visitors (only for Admin and Guard) -->
    <h3 class="print-title">Walk-in Visitors</h3>
    <table id="walkinVisitorsTable">
        <thead>
            <tr>
                <th>No</th>
                <th>Visitor Name</th>
                <th>Email</th>
                <th>Phone</th>
                <th>Arrival Time</th>
                <th>Leave Time</th>
                <th>Status</th>
            </tr>
        </thead>
        <tbody>
            <?php 
            $counter = 1;
            while ($row = mysqli_fetch_assoc($result_walkin)): ?>
                <tr>
                    <td><?php echo $counter++; ?></td>
                    <td><?php echo htmlspecialchars($row['name']); ?></td>
                    <td><?php echo htmlspecialchars($row['email']); ?></td>
                    <td><?php echo htmlspecialchars($row['phone']); ?></td>
                    <td><?php echo htmlspecialchars($row['Arrive'] !== null ? $row['Arrive'] : 'N/A'); ?></td>
                    <td><?php echo htmlspecialchars($row['Leave_Time'] !== null ? $row['Leave_Time'] : 'N/A'); ?></td>
                    <td><?php echo htmlspecialchars($row['status']); ?></td>
                </tr>
            <?php endwhile; ?>
        </tbody>
    </table>
<?php endif; ?>
    <div>
        <button type="button" id="printButton" onclick="print12()">Print</button>
    </div>

<script>
    // Column toggle logic
    function toggleColumn(index) {
        let checkboxes = document.querySelectorAll(".dropdown-content input[type='checkbox']");
        let columns = document.querySelectorAll("table th, table td");
        
        columns.forEach((col, i) => {
            if (i === index || i % 7 === index) {
                col.style.display = checkboxes[index].checked ? "" : "none";
            }
        });
    }
    
     // Print table
    function print12() {
        window.print();
    }

    // Toggle dropdown visibility
    function toggleDropdown() {
        document.getElementById("myDropdown").classList.toggle("show");
    }

    // Global search functionality
    function filterTable() {
        let input = document.getElementById("globalSearch");
        let filter = input.value.toLowerCase();
        let tables = document.querySelectorAll("table");
        
        tables.forEach(table => {
            let rows = table.getElementsByTagName("tr");
            for (let i = 0; i < rows.length; i++) {
                let cells = rows[i].getElementsByTagName("td");
                let found = false;
                for (let j = 0; j < cells.length; j++) {
                    if (cells[j] && cells[j].innerText.toLowerCase().includes(filter)) {
                        found = true;
                        break;
                    }
                }
                rows[i].style.display = found ? "" : "none";
            }
        });
    }
</script>

</body>
</html>
