<?php
// Include your database connection file
include('dbconn.php');

// Fetch visitor details from the visitor_details table with status
$sql_visitor_details = "SELECT *, 
                            CASE 
                                WHEN (Arrive IS NULL OR Arrive = 'N/A') AND (Leave_Time IS NULL OR Leave_Time = 'N/A') THEN 'pending'
                                WHEN Arrive IS NOT NULL AND Leave_Time IS NULL THEN 'arrived'
                                WHEN Leave_Time IS NOT NULL THEN 'left'
                                ELSE 'unknown'
                            END AS status 
                        FROM visitor_details"; 
$query_visitor_details = mysqli_query($db, $sql_visitor_details);

if (!$query_visitor_details) {
    die("Query failed: " . mysqli_error($db));
}

// Fetch walk-in visitor details from the walkin_visitors table
$sql_walkin_visitors = "SELECT *, 
                            CASE 
                                WHEN (Arrive IS NULL OR Arrive = 'N/A') AND (Leave_Time IS NULL OR Leave_Time = 'N/A') THEN 'pending'
                                WHEN Arrive IS NOT NULL AND Leave_Time IS NULL THEN 'arrived'
                                WHEN Leave_Time IS NOT NULL THEN 'left'
                                ELSE 'unknown'
                            END AS status 
                        FROM walkin_visitors";
$query_walkin_visitors = mysqli_query($db, $sql_walkin_visitors);

if (!$query_walkin_visitors) {
    die("Query failed: " . mysqli_error($db));
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Scan QR - Visitor Details</title>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/html5-qrcode/2.3.4/html5-qrcode.min.js" integrity="sha512-k/KAe4Yff9EUdYI5/IAHlwUswqeipP+Cp5qnrsUjTPCgl51La2/JhyyjNciztD7mWNKLSXci48m7cctATKfLlQ==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
    <style>
        body {
            font-family: 'Arial', sans-serif;
            background-color: #f4f7fc;
            margin: 0;
            padding: 0;
            color: #333;
        }
        .container {
            max-width: 570px;
            margin: 0 auto;
            padding: 20px;
        }
        .controls {
            text-align: center;
            margin-bottom: 20px;
        }

        #reader {
            margin-top: 20px;
            width: 100%;
            max-width: 400px;
            margin: 0 auto;
            display: block;
        }

        #result {
            text-align: center;
            margin-top: 20px;
            font-size: 12px;
            padding: 15px;
            background-color: #fff;
            border: 1px solid #ddd;
            box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
        }

        h2 {
            text-align: center;
            color: #0066cc;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
        }

        th, td {
            padding: 12px;
            text-align: left;
            border: 1px solid #ddd;
        }

        th {
            background-color: #0066cc;
            color: white;
            text-align: center;
        }

        td {
            text-align: center;
        }

        td a {
            color: #0066cc;
            font-weight: bold;
            text-decoration: none;
        }

        td a:hover {
            text-decoration: underline;
        }

        #visitorList {
            display: none;
        }

        .action-button {
            display: inline-block;
            padding: 10px 20px;
            margin-top: 20px;
            background-color: #0066cc;
            color: #fff;
            text-decoration: none;
            border-radius: 5px;
            font-size: 16px;
            transition: background-color 0.3s;
        }

        .action-button:hover {
            background-color: #005bb5;
        }
    </style>
</head>
<body>
     <h1>Scan QR</h1>
     <br>

<div class="container">

    <main>
        <div id="reader"></div>
        <div id="result"></div>
    </main>

    <h2>Visitor List</h2>
    <table id="visitorList">
        <thead>
            <tr>
                <th>Visitor ID</th>
                <th>Name</th>
                <th>Status</th>
            </tr>
        </thead>
        <tbody>
            <!-- Regular Visitors -->
            <?php while ($row = mysqli_fetch_assoc($query_visitor_details)): ?>
                <tr id="visitor_<?php echo $row['ID']; ?>" data-request-form-no="<?php echo $row['Request_Form_No']; ?>">
                    <td><a href="visitor_details.php?visitor_id=<?php echo $row['ID']; ?>" target="_blank">
                        <?php echo 'Pre-Registration -' . htmlspecialchars($row['ID']); ?>
                    </a></td>
                    <td><?php echo htmlspecialchars($row['Name']); ?></td>
                    <td><?php echo htmlspecialchars($row['status']); ?></td>
                </tr>
            <?php endwhile; ?>

            <!-- Walk-in Visitors -->
            <?php while ($row = mysqli_fetch_assoc($query_walkin_visitors)): ?>
                <tr id="walkin_<?php echo $row['ID']; ?>" data-request-form-no="<?php echo $row['request_form_no']; ?>">
                    <td><a href="visitor_details.php?visitor_id=<?php echo $row['ID']; ?>" target="_blank">
                        <?php echo 'Walkin -' . htmlspecialchars($row['ID']); ?>
                    </a></td>
                    <td><?php echo htmlspecialchars($row['name']); ?></td>
                    <td><?php echo htmlspecialchars($row['status']); ?></td>
                </tr>
            <?php endwhile; ?>
        </tbody>
    </table>
</div>

<script>
// QR Code scanning logic
let scanner;

function success(result) {
    const resultParts = result.split('?id=');
    
    if (resultParts.length > 1) {
        const requestFormNo = resultParts[1]; 
        
        // Display the result information
        const resultHtml = `
            <h2><strong>Visitor ID: ${requestFormNo}</strong></h2>
            <p>Scanned QR Code: ${result}</p>
        `;
        document.getElementById('result').innerHTML = resultHtml;

        // Show the visitor list after QR scan
        showVisitorByRequestFormNo(requestFormNo);

        // Clear the scanner
        scanner.clear();
        document.getElementById('reader').remove();
    } else {
        document.getElementById('result').innerHTML = "<p>Invalid QR Code</p>";
    }
}

function showVisitorByRequestFormNo(requestFormNo) {
    const visitorList = document.getElementById('visitorList');
    const rows = visitorList.getElementsByTagName('tr');
    let found = false;

    // Hide all visitors first
    for (let i = 0; i < rows.length; i++) {
        rows[i].style.display = 'none'; // Hide all rows
    }

    // Find and show the specific visitor by Request Form No
    for (let i = 0; i < rows.length; i++) {
        const visitorRequestFormNo = rows[i].getAttribute('data-request-form-no');

        if (visitorRequestFormNo === requestFormNo) {
            rows[i].style.display = 'table-row'; // Show the matching visitor
            found = true;
        }
    }

    // Show the visitor list only after a scan
    if (found) {
        visitorList.style.display = 'table'; // Make sure it's displayed
    } else {
        document.getElementById('result').innerHTML += "<p>No visitor found with that Request Form No.</p>";
    }
}

function startScanner() {
    scanner = new Html5QrcodeScanner("reader", { fps: 10, qrbox: 250 });
    scanner.render(success);
}

startScanner();

// Search functionality
function filterTable() {
    const input = document.getElementById("globalSearch");
    const filter = input.value.toLowerCase();
    const visitorList = document.getElementById('visitorList');
    const rows = visitorList.getElementsByTagName('tr');
    
    // Loop through all rows and hide those who don't match the search term
    for (let i = 0; i < rows.length; i++) {
        const cells = rows[i].getElementsByTagName('td');
        if (cells.length > 0) {
            const name = cells[1].textContent || cells[1].innerText;
            if (name.toLowerCase().indexOf(filter) > -1) {
                rows[i].style.display = "";
            } else {
                rows[i].style.display = "none";
            }
        }
    }
}
</script>

</body>
</html>
