<?php
session_start();
require 'dbconn.php'; // Include your database connection file

// Function to redirect with a success message
function redirectWithMessage($message, $location) {
    $_SESSION['success_message'] = $message;
    header("Location: $location");
    exit();
}

// Check if an action is set
if (isset($_GET['action']) && isset($_GET['id'])) {
    $id = intval($_GET['id']); // Ensure the ID is an integer
    if ($_GET['action'] === 'approve') {
        // Prepare and execute the approval query
        $stmt = $db->prepare("UPDATE visitors SET status = 'approved' WHERE id = :id");
        $stmt->bindParam(':id', $id);
        if ($stmt->execute()) {
            redirectWithMessage("Visitor approved successfully.", "visitor_action.php");
        } else {
            redirectWithMessage("Failed to approve visitor.", "visitor_action.php");
        }
    } elseif ($_GET['action'] === 'reject') {
        // Prepare and execute the rejection query
        $stmt = $db->prepare("UPDATE visitors SET status = 'rejected' WHERE id = :id");
        $stmt->bindParam(':id', $id);
        if ($stmt->execute()) {
            redirectWithMessage("Visitor rejected successfully.", "visitor_action.php");
        } else {
            redirectWithMessage("Failed to reject visitor.", "visitor_action.php");
        }
    } else {
        redirectWithMessage("Invalid action.", "visitor_action.php");
    }
}

// Display the success message
$message = isset($_SESSION['success_message']) ? $_SESSION['success_message'] : null;
unset($_SESSION['success_message']); // Clear the message after displaying it
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Visitor Action</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f4f4f4;
            text-align: center;
            padding: 50px;
        }
        .message {
            background-color: #28a745; /* Green background */
            color: white; /* White text */
            padding: 15px;
            border-radius: 5px;
            display: inline-block;
            margin-bottom: 20px;
        }
        a {
            text-decoration: none;
            color: #007bff; /* Bootstrap primary color */
            font-weight: bold;
        }
    </style>
</head>
<body>

    <?php if ($message): ?>
        <div class="message"><?php echo htmlspecialchars($message); ?></div>
    <?php endif; ?>

    <p>
        <a href="your_main_page.php">Go back to Visitors List</a>
    </p>

</body>
</html>
