<?php
include('dbconn.php');

// Check if user is logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}

// Fetch the logged-in user's name
$user_id = $_SESSION['user_id'];
$sqlUser = "SELECT name FROM login_user WHERE id = ?";
$stmtUser = $db->prepare($sqlUser);
$stmtUser->bind_param("i", $user_id); // 'i' indicates the type is integer
$stmtUser->execute();
$userResult = $stmtUser->get_result();

if ($userResult->num_rows > 0) {
    $user = $userResult->fetch_assoc();
    $hostName = $user['name']; // Assuming you want to filter by the user's name
} else {
    die("User not found.");
}

// Fetch visitor details for the specified host name
$sqlVisitors = "SELECT ID, General_Email, Host, Department, created_at, Status 
                FROM visitors 
                WHERE Host = ?"; // Filter by Host name
$stmtVisitors = $db->prepare($sqlVisitors);
$stmtVisitors->bind_param("s", $hostName); // 's' indicates the type is string
$stmtVisitors->execute();
$queryVisitors = $stmtVisitors->get_result();

if (!$queryVisitors) {
    die("Query failed: " . $db->error);
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>My Requests</title>
    <style>
        /* Basic reset for margins, paddings */
        body, h1, p {
            margin: 0;
            padding: 0;
        }

        /* Body and overall page styling */
        body {
            font-family: 'Poppins', sans-serif;
            background-color: #f4f4f9;
            margin: 0;
        }

        h1 {
            margin-bottom: 20px;
            text-align: center;
        }

        /* Flex container for search bar and dropdown */
        .form-container {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
            width: 80%; /* Match the table width */
            margin: 0 auto;
        }

        /* Search Bar and Column Toggle Container */
        .search-container {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
        }

        #globalSearch {
            padding: 8px;
            width: 82%;
            margin-right: 10px;
            border: 1px solid #333;
            border-radius: 5px;
            font-size: 14px;
        }
        
         #globalSearch:focus {
            border-color: #0056b3;
        }
        
        button {
            padding: 8px 16px;
            background-color: #0066cc;
            color: white;
            border: none;
            cursor: pointer;
            border-radius: 5px;
            font-size: 16px;
            margin: 5px;
        }

        /* Dropdown container styling */
        .dropdown {
            display: inline-block;
            position: relative;
        }

        /* Button inside dropdown */
        .dropdown button {
            padding: 8px 16px;
            background-color: #0066cc;
            color: white;
            border: none;
            cursor: pointer;
            font-size: 14px;
            border-radius: 4px;
            text-align: center;
            width: 150px;
        }

        /* Dropdown content (hidden by default) */
        .dropdown-content {
            display: none;
            position: absolute;
            background-color: #f9f9f9;
            min-width: 160px;
            box-shadow: 0px 8px 16px 0px rgba(0, 0, 0, 0.2);
            z-index: 1;
            border-radius: 4px;
        }

        .dropdown-content label {
            display: flex;
            align-items: center;
            padding: 8px 16px;
            cursor: pointer;
        }

        /* Checkbox styling */
        .dropdown-content input[type="checkbox"] {
            margin-right: 8px;
            accent-color: #4CAF50;
        }

        /* Hover effect on dropdown items */
        .dropdown-content label:hover {
            background-color: #ddd;
        }

        /* Table styling */
        table {
            width: 79%; /* Set the table width */
            border-collapse: collapse;
            margin-top: 20px;
            margin-left: auto;
            margin-right: auto;
        }

        td, th {
            text-align: center;
            padding: 10px;
            font-size: 12px;
            border: 1px solid #ddd;
        }

        th {
            background-color: #f2f2f2;
            color: #333;
            font-weight: bold;
        }
        tr:nth-child(even) {
            background-color: #f9f9f9;
        }

        tr:nth-child(odd) {
            background-color: #fff;
        }

        .status {
            font-weight: bold;
        }

        .pending {
            color: #ff9800;
        }

        .approved {
            color: #28a745;
        }

        .rejected {
            color: #dc3545;
        }

        /* Sort icon styles */
        .sort-icon {
            display: inline-block;
            width: 0;
            height: 0;
            border-left: 4px solid transparent;
            border-right: 4px solid transparent;
            margin-left: 5px;
            vertical-align: middle;
        }

        /* Upward arrow (ascending) */
        .sort-icon.asc {
            border-bottom: 6px solid #4CAF50;
        }

        /* Downward arrow (descending) */
        .sort-icon.desc {
            border-top: 6px solid #4CAF50;
        }

        /* Print layout */
        @media print {
            body * {
                visibility: hidden; /* Hide all elements */
            }
            #visitorsTable, #visitorsTable * {
                visibility: visible; /* Show the visitors table and its contents */
            }
            #visitorsTable {
                position: relative; /* Use relative positioning for the table */
                width: 100%; /* Ensure the table uses the full width */
            }
            h1 {
                visibility: visible; /* Show the heading for context */
                text-align: center; /* Center the heading */
            }
        }
    </style>
</head>
<body>
    <h2>My Requests</h2>
    <br>

    <div class="form-container">
        <!-- Search Bar -->
        <input type="text" id="globalSearch" placeholder="Search in table..." onkeyup="filterTable()">
        
        <!-- Column Toggle Dropdown -->
        <div class="dropdown">
            <button onclick="toggleDropdown()">Toggle Columns</button>
            <div id="myDropdown" class="dropdown-content">
                <label><input type="checkbox" checked onchange="toggleColumn(1)"> Host Name</label>
                <label><input type="checkbox" checked onchange="toggleColumn(2)"> Email</label>
                <label><input type="checkbox" checked onchange="toggleColumn(3)"> Department</label>
                <label><input type="checkbox" checked onchange="toggleColumn(4)"> Created At</label>
                <label><input type="checkbox" checked onchange="toggleColumn(5)"> Status</label>
            </div>
        </div>
    </div>

    <table id="visitorsTable">
        <thead>
            <tr>
                <th onclick="sortTable(0)">No. <span id="sort-icon-0" class="sort-icon"></span></th>
                <th onclick="sortTable(1)">Host Name <span id="sort-icon-1" class="sort-icon"></span></th>
                <th onclick="sortTable(2)">Email <span id="sort-icon-2" class="sort-icon"></span></th>
                <th onclick="sortTable(3)">Department <span id="sort-icon-3" class="sort-icon"></span></th>
                <th onclick="sortTable(4)">Created At <span id="sort-icon-4" class="sort-icon"></span></th>
                <th onclick="sortTable(5)">Status <span id="sort-icon-5" class="sort-icon"></span></th>
            </tr>
        </thead>
        <tbody>
            <?php 
            if ($queryVisitors->num_rows > 0):
                $count = 1;
                while ($row = $queryVisitors->fetch_assoc()):
                    // Set alternating row colors
                    $rowColor = ($count % 2 == 0) ? '#f8f9fa' : '#ffffff'; // Light grey for even rows, white for odd rows
            ?>
                    <tr style="background-color: <?php echo $rowColor; ?>;">
                        <td><?php echo $count++; ?></td>
                        <td><?php echo htmlspecialchars($row['Host']); ?></td>
                        <td><?php echo htmlspecialchars($row['General_Email']); ?></td>
                        <td><?php echo htmlspecialchars($row['Department']); ?></td>
                        <td><?php echo htmlspecialchars($row['created_at']); ?></td>
                        <td class="status <?php echo strtolower(htmlspecialchars($row['Status'])); ?>">
                            <?php echo htmlspecialchars($row['Status']); ?>
                        </td>
                    </tr>
            <?php endwhile; ?>
            <?php else: ?>
                <tr>
                    <td colspan="6">No requests found.</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>
    
     <div>
        <button type="button" id="printButton" onclick="print12()">Print</button>
    </div>

    <script type="text/javascript">
        let sortDirection = [true, true, true, true, true]; // Track sorting direction for each column (ascending or descending)
        let columnVisibility = [true, true, true, true, true, true]; // Track visibility of each column (including No. column)

        function print12() {
            window.print();
        }

        function filterTable() {
            var input, filter, table, tr, td, i, j, txtValue;
            input = document.getElementById("globalSearch");
            filter = input.value.toUpperCase();
            table = document.getElementById("visitorsTable");
            tr = table.getElementsByTagName("tr");

            for (i = 1; i < tr.length; i++) {
                tr[i].style.display = "none"; 
                for (j = 1; j < tr[i].cells.length; j++) { // Start from 1 to skip the counter column
                    td = tr[i].getElementsByTagName("td")[j];
                    if (td) {
                        txtValue = td.textContent || td.innerText;
                        if (txtValue.toUpperCase().indexOf(filter) > -1) {
                            tr[i].style.display = ""; 
                            break; 
                        }
                    }
                }
            }
        }

        // Toggle visibility of columns based on checkbox selection
        function toggleColumn(colIndex) {
            const table = document.getElementById("visitorsTable");
            const cells = table.querySelectorAll(`td:nth-child(${colIndex + 1}), th:nth-child(${colIndex + 1})`);

            // Update column visibility status
            columnVisibility[colIndex] = !columnVisibility[colIndex];

            cells.forEach(cell => {
                cell.style.display = columnVisibility[colIndex] ? "" : "none";
            });
        }

        // Show or hide the dropdown content when clicking the button
        function toggleDropdown() {
            const dropdownContent = document.getElementById("myDropdown");
            dropdownContent.style.display = dropdownContent.style.display === 'block' ? 'none' : 'block';
        }

        // Close the dropdown if the user clicks outside of it
        window.addEventListener('click', function(event) {
            const dropdown = document.querySelector('.dropdown');
            if (!dropdown.contains(event.target)) {
                const dropdownContent = document.getElementById("myDropdown");
                dropdownContent.style.display = 'none';
            }
        });

        function sortTable(colIndex) {
            const table = document.getElementById("visitorsTable");
            const rows = Array.from(table.rows).slice(1); // Get all rows excluding the header row
            const isAscending = sortDirection[colIndex];

            rows.sort((rowA, rowB) => {
                const cellA = rowA.cells[colIndex].innerText.toLowerCase();
                const cellB = rowB.cells[colIndex].innerText.toLowerCase();

                if (isAscending) {
                    return cellA > cellB ? 1 : (cellA < cellB ? -1 : 0);
                } else {
                    return cellA < cellB ? 1 : (cellA > cellB ? -1 : 0);
                }
            });

            sortDirection[colIndex] = !isAscending; // Reverse sort direction for next time

            rows.forEach(row => table.appendChild(row)); // Reattach sorted rows

            // Update sort icon
            updateSortIcon(colIndex, isAscending);
        }

        function updateSortIcon(colIndex, isAscending) {
            // Reset all icons first
            const icons = document.querySelectorAll('.sort-icon');
            icons.forEach(icon => icon.classList.remove('asc', 'desc'));

            // Update the icon for the current column
            const icon = document.getElementById(`sort-icon-${colIndex}`);
            icon.classList.add(isAscending ? 'asc' : 'desc');
        }
    </script>
</body>
</html>
