<?php

ini_set('display_errors', 1); // Show errors in browser (disable this in production)
error_reporting(E_ALL); // Report all types of errors

// Log errors to a file
ini_set('log_errors', 1);
ini_set('error_log', 'error_log.txt'); // Change this to your preferred log file path

// Include database connection, FPDF, and PHPMailer classes
require_once 'dbconn.php';
require_once 'fpdf.php'; // Ensure the path is correct
require 'sendemail/src/Exception.php';
require 'sendemail/src/PHPMailer.php';
require 'sendemail/src/SMTP.php';

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

// Function to send email
function sendEmail($mail, $recipient, $subject, $body, $attachment = null, $ccRecipient = null) {
    try {
        $mail->setFrom('farzana@umedichealthcare.com', 'UMedic Healthcare');
        $mail->addAddress($recipient); // Send to the recipient
        
        if ($ccRecipient) {
            $mail->addCC($ccRecipient); // Add CC recipient (host's general email)
        }

        $mail->Subject = $subject;

        // Use HTML email format
        $mail->isHTML(true);
        $styledBody = "<html>
            <body style='font-family: Arial, sans-serif; font-size: 14px; color: #333;'>
                <h2 style='color: #333;'>$subject</h2>
                <p>$body</p>
                <p style='margin-top: 20px; font-size: 12px; color: #888;'>Thank you,</p>
                <p style='font-weight: bold;'>UMedic Healthcare</p>
            </body>
        </html>";

        $mail->Body = $styledBody;

        if ($attachment) {
            $mail->addAttachment($attachment); // Attach the PDF if available
        }

        return $mail->send();
    } catch (Exception $e) {
        return false;
    } finally {
        $mail->clearAddresses();
    }
}

// Function to generate PDF
function generatePDF($visitor, $request_form_no) {
    // Initialize PDF
    $pdf = new FPDF();
    $pdf->AddPage();

    // Header styling
    $pdf->SetFont('Arial', 'B', 14);
    $pdf->Cell(0, 10, "Visit Pass Approval", 0, 1, 'C');
    $pdf->Ln(10);

    // Visitor Details Section
    $pdf->SetFont('Arial', 'B', 14);
    $pdf->Cell(0, 10, "Visitor Details", 0, 1, 'L');
    $pdf->Ln(5);

    // Visitor details
    $pdf->SetFont('Arial', 'B', 14); // Set font to bold for the "Request Form No"
    $pdf->SetTextColor(0, 0, 0);
    $pdf->Cell(90, 10, "" . htmlspecialchars($visitor['Request_Form_No']), 0, 1);
    
    $pdf->SetFont('Arial', '', 14);
    $pdf->SetTextColor(0, 0, 0);
    $pdf->Cell(90, 10, "Name: " . htmlspecialchars($visitor['Name']), 0, 1);
    $pdf->Cell(90, 10, "Email: " . htmlspecialchars($visitor['Email']), 0, 1);
    $pdf->Cell(90, 10, "Phone No: " . htmlspecialchars($visitor['Phone']), 0, 1);

    // Generate QR Code URL with your domain and visitor ID (Request_Form_No)
    $qrData = "https://visitor.umedic.com.my/visitor?id=" . urlencode($visitor['Request_Form_No']);
    $qrCodeUrl = "https://api.qrserver.com/v1/create-qr-code/?size=100x100&data=" . urlencode($qrData);

    // Create temporary file for storing the QR code image
    $qrCodeFile = tempnam(sys_get_temp_dir(), 'qr_') . '.png';
    file_put_contents($qrCodeFile, file_get_contents($qrCodeUrl));

    // Add the QR code image to the PDF
    $pdf->Image($qrCodeFile, 150, 40, 40, 40);  // Position of the QR code in PDF

    // Make the QR code clickable in the PDF
    $pdf->SetTextColor(0, 0, 255);  // Set hyperlink color (blue)
    $pdf->Link(150, 40, 40, 40, $qrData);  // Make the QR code clickable (link to visitor page)

    // Clean up the temporary QR code file
    unlink($qrCodeFile);

    // Host/Interviewer Details Section
    $pdf->SetFont('Arial', 'B', 14);
    $pdf->SetTextColor(0, 51, 102);
    $pdf->Cell(0, 10, "Host/Interviewer Details", 0, 1, 'L');
    $pdf->Ln(5);

    // Host/Interviewer Details
    $fields = [
        'Host' => 'Host/Interviewer',
        'General_Email' => 'Email',
        'Visitor_Type' => 'Visitor Type',
        'Department' => 'Department',
        'Meeting_Room' => 'Meeting Room',
        'Approver' => 'Approver',
        'Plan_Date_Time_In' => 'Date & Time In',
        'Plan_Date_Time_Out' => 'Date & Time Out'
    ];

    $pdf->SetFont('Arial', '', 12);
    foreach ($fields as $key => $label) {
        $value = htmlspecialchars($visitor[$key] ?? 'N/A');
        $pdf->Cell(90, 10, "$label:", 0);
        $pdf->Cell(0, 10, $value, 0, 1);
    }

    // Define file path and ensure directory exists
    $pdfDirectory = 'public_html/vms/pdfs/';
    if (!file_exists($pdfDirectory)) {
        mkdir($pdfDirectory, 0777, true);
    }

    // Generate unique file name and save PDF
    $fileName = '' . $request_form_no . '.pdf'; // Use Request Form No as file name
    $pdfFilePath = $pdfDirectory . $fileName;
    $pdf->Output('F', $pdfFilePath);

    return $pdfFilePath;
}



// Handle approval or rejection of a visitor pass
if (isset($_GET['action']) && isset($_GET['id'])) {
    $action = $_GET['action'];
    $id = intval($_GET['id']);

    if (!in_array($action, ['approve', 'reject'])) {
        exit;
    }

    $mail = new PHPMailer(true);
    try {
        // SMTP configuration
        $mail->isSMTP();
        $mail->Host = 'mail.umedichealthcare.com';
        $mail->SMTPAuth = true;
        $mail->Username = 'farzana@umedichealthcare.com';
        $mail->Password = '385003&+Umc'; 
        $mail->SMTPSecure = 'ssl';
        $mail->Port = 465;
        $mail->SMTPDebug = 0;

        // Initialize flag for host email
        $hostEmailSent = false;

        // Update the visitor status based on action
        $status = $action === 'approve' ? 'approved' : 'rejected';
        $stmt = $db->prepare("UPDATE visitors SET Status = ? WHERE ID = ?");
        $stmt->bind_param('si', $status, $id);
        $stmt->execute();

        // Check for any errors in updating the status
        if ($stmt->error) {
            die('Error updating visitor status: ' . $stmt->error);
        }

        // Prepare and execute the query to fetch visitor details
        $stmtEmail = $db->prepare("SELECT vd.Email, vd.Name, vd.Phone, v.General_Email, v.Host, v.Visitor_Type, v.Department, v.Meeting_Room, v.Approver, v.Plan_Date_Time_In, v.Plan_Date_Time_Out, v.Request_Form_No, v.Purpose
                                    FROM visitor_details vd 
                                    JOIN visitors v ON vd.Visitor_ID = v.ID 
                                    WHERE v.ID = ?");

        $stmtEmail->bind_param('i', $id);
        $stmtEmail->execute();
        
        $result = $stmtEmail->get_result();

        // Process each visitor individually
        while ($visitor = $result->fetch_assoc()) {
            // Check if Request_Form_No is empty, if not generate it
            if (empty($visitor['Request_Form_No'])) {
                $prefix = "VMS-" . date('Ym');
                $code = sprintf("%'.04d", 1);

                while (true) {
                    $check = $db->query("SELECT COUNT(*) as count FROM `visitors` WHERE Request_Form_No = '{$prefix}{$code}'")->fetch_assoc()['count'];
                    if ($check > 0) {
                        $code = sprintf("%'.04d", intval(substr($code, -4)) + 1);
                    } else {
                        break;
                    }
                }

                $visitor['Request_Form_No'] = $prefix . $code;
            }
            
            // Send email to host if visitor pass is approved and email not sent yet
            if ($action === 'approve' && !$hostEmailSent) {
                $subject_host = "Visitor Pass Approved";
                $body_host = "<html>
                                <body>
                                    <p>Your request has been successfully approved. Below are the details:</p>
                                    <ul>
                                        <li><strong>Request Form No:</strong> " . htmlspecialchars($visitor['Request_Form_No']) . "</li>
                                        <li><strong>Visitor Type:</strong> " . htmlspecialchars($visitor['Visitor_Type']) . "</li>
                                        <li><strong>Purpose:</strong> " . htmlspecialchars($visitor['Purpose']) . "</li>
                                        <li><strong>Planned Date & Time In:</strong> " . htmlspecialchars($visitor['Plan_Date_Time_In']) . "</li>
                                        <li><strong>Planned Date & Time Out:</strong> " . htmlspecialchars($visitor['Plan_Date_Time_Out']) . "</li>
                                        <li><strong>Meeting Room:</strong> " . htmlspecialchars($visitor['Meeting_Room']) . "</li>
                                        <li><strong>Host Name:</strong> " . htmlspecialchars($visitor['Host']) . "</li>
                                    </ul>
                                </body>
                            </html>";

                if (sendEmail($mail, $visitor['General_Email'], $subject_host, $body_host, null)) {

                    $hostEmailSent = true;
                } else {
                    echo "Failed to send approval email to host.<br>";
                }
            }

           // Send rejection email to host
if ($action === 'reject' && !$hostEmailSent) {
    $subject_host = "Visitor Pass Rejected";
    $body_host = "<html>
                    <body>
                        <p>Your request has been rejected. Below are the details:</p>
                        <ul>
                            <li><strong>Request Form No:</strong> " . htmlspecialchars($visitor['Request_Form_No']) . "</li>
                            <li><strong>Visitor Type:</strong> " . htmlspecialchars($visitor['Visitor_Type']) . "</li>
                            <li><strong>Purpose:</strong> " . htmlspecialchars($visitor['Purpose']) . "</li>
                            <li><strong>Planned Date & Time In:</strong> " . htmlspecialchars($visitor['Plan_Date_Time_In']) . "</li>
                            <li><strong>Planned Date & Time Out:</strong> " . htmlspecialchars($visitor['Plan_Date_Time_Out']) . "</li>
                            <li><strong>Meeting Room:</strong> " . htmlspecialchars($visitor['Meeting_Room']) . "</li>
                            <li><strong>Host Name:</strong> " . htmlspecialchars($visitor['Host']) . "</li>
                        </ul>
                    </body>
                </html>";

    if (sendEmail($mail, $visitor['General_Email'], $subject_host, $body_host, null)) {
        // Host email sent successfully
        $hostEmailSent = true;
    } else {
        echo "Failed to send rejection email to host.<br>";
    }
}

// Send email to visitor (approve or reject) with PDF and CC host's general email
$subject_visitor = $action === 'approve' ? "Visitor Pass Approved" : "Visitor Pass Rejected";
$body_visitor = $action === 'approve' 
                ? "Dear " . htmlspecialchars($visitor['Name']) . ",<br>Your visit to UMC on <strong>" . htmlspecialchars($visitor['Plan_Date_Time_In']) . "</strong> is <strong>Approved</strong>.<br>Scan and show your QR code when you arrive at the guard post." 
                : "Dear " . htmlspecialchars($visitor['Name']) . ",<br>Your visit to UMC on <strong>" . htmlspecialchars($visitor['Plan_Date_Time_In']) . "</strong> has been <strong>Rejected</strong>.<br>We regret to inform you that your visit could not be approved.";

// Generate PDF for approved visitor
$pdfFilePath = null;
if ($action === 'approve') {
    $pdfFilePath = generatePDF($visitor, $visitor['Request_Form_No']);
}

// Send the email to the visitor and attach the PDF (if approved)
if (sendEmail($mail, $visitor['Email'], $subject_visitor, $body_visitor, $pdfFilePath, $visitor['General_Email'])) {
    // If the email was successfully sent, then redirect after all emails have been sent
    if ($action === 'approve') {
        // Redirect to thank_you4.php for approved visitors
        header('Location: thank_you4.php');
        exit;
    } elseif ($action === 'reject') {
        // Redirect to thank_you3.php for rejected visitors
        header('Location: thank_you3.php');
        exit;
    }
} else {
    echo "Failed to send email to visitor.<br>";
}

        }

    } catch (Exception $e) {
        echo "Error: {$e->getMessage()}<br>";
    }
}
?>
