<?php
// Include database connection, FPDF, and PHPMailer classes
require_once 'dbconn.php';
require_once 'fpdf.php'; // Ensure the path is correct
require 'sendemail/src/Exception.php';
require 'sendemail/src/PHPMailer.php';
require 'sendemail/src/SMTP.php';

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

// Function to send email
function sendEmail($mail, $recipientEmails, $subject, $body, $attachment = null, $ccRecipient = null) {
    try {
        $mail->setFrom('farzana@umedichealthcare.com', 'UMedic Healthcare');

        // Add all email addresses to the "To" or "BCC" field
        foreach ($recipientEmails as $email) {
            $mail->addAddress($email);
        }
        
        if ($ccRecipient) {
            $mail->addCC($ccRecipient); // Add CC recipient (host's general email)
        }

        $mail->Subject = $subject;

        // Use HTML email format
        $mail->isHTML(true);
        $styledBody = "<html>
            <body style='font-family: Arial, sans-serif; font-size: 14px; color: #333;'>
                <h2 style='color: #333;'>$subject</h2>
                <p>$body</p>
                <p style='margin-top: 20px; font-size: 12px; color: #888;'>Thank you,</p>
                <p style='font-weight: bold;'>UMedic Healthcare</p>
            </body>
        </html>";

        $mail->Body = $styledBody;

        if ($attachment) {
            $mail->addAttachment($attachment); // Attach the QR code if available
        }

        return $mail->send();
    } catch (Exception $e) {
        return false;
    } finally {
        $mail->clearAddresses();
    }
}

// Handle visitor form submission (Pending notice)
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Collect and sanitize form data
    $general_email = mysqli_real_escape_string($db, $_POST['general_email']);
    $visitor_type = mysqli_real_escape_string($db, $_POST['visitor_type']);
    $department = mysqli_real_escape_string($db, $_POST['department']);
    $purpose = mysqli_real_escape_string($db, $_POST['purpose']);
    $person_meet = mysqli_real_escape_string($db, $_POST['person_meet']);
    $meeting_room = mysqli_real_escape_string($db, $_POST['meeting_room']);
    $approver = mysqli_real_escape_string($db, $_POST['approver']);
    $plan_date_time_in = mysqli_real_escape_string($db, $_POST['plan_date_time_in']);
    $plan_date_time_out = mysqli_real_escape_string($db, $_POST['plan_date_time_out']);

    $visitor_names = $_POST['name'];
    $visitor_emails = $_POST['email'];
    $visitor_phones = $_POST['phone'];
    $visitor_ics = $_POST['ic'];
    $visitor_vehicle_reg_nos = $_POST['vehicle_reg_no'];

    // Generate Request_Form_No
    $prefix = "VMS-" . date('Ym'); // VMS-YYYYMM (e.g., VMS-202411)
    $code = sprintf("%'.04d", 1); // Start at 0001

    while (true) {
        // Check if the generated Request_Form_No already exists in the database
        $check = $db->query("SELECT COUNT(*) as count FROM `visitor_details` WHERE Request_Form_No = '{$prefix}{$code}'")->fetch_assoc()['count'];
        
        // If the code exists, increment it and try again
        if ($check > 0) {
            $code = sprintf("%'.04d", intval(substr($code, -4)) + 1);
        } else {
            break; // Unique Request_Form_No found
        }
    }

    // Generate the unique Request_Form_No
    $request_form_no = $prefix . $code;

    // Insert visitor data into the visitors table with Request Form No
    $insertVisitorSql = "INSERT INTO visitors (General_Email, Visitor_Type, Department, Purpose, Host, Meeting_Room, Approver, Plan_Date_Time_In, Plan_Date_Time_Out, Status, Request_Form_No, qr_code_data, created_at) 
                         VALUES ('$general_email', '$visitor_type', '$department', '$purpose', '$person_meet', '$meeting_room', '$approver', '$plan_date_time_in', '$plan_date_time_out', 'Pending', '$request_form_no', '', NOW())";

    if (mysqli_query($db, $insertVisitorSql)) {
        $visitor_id = mysqli_insert_id($db); // Get the inserted visitor's ID

        // Loop through each visitor and insert their details
        foreach ($visitor_names as $index => $name) {
            $name = mysqli_real_escape_string($db, $name);
            $email = mysqli_real_escape_string($db, $visitor_emails[$index]);
            $phone = mysqli_real_escape_string($db, $visitor_phones[$index]);
            $ic = mysqli_real_escape_string($db, $visitor_ics[$index]);
            $vehicle_reg_no = mysqli_real_escape_string($db, $visitor_vehicle_reg_nos[$index]);
            $created_by = $_SESSION['user']; // User who created the record

            // Insert each visitor's details into the visitor_details table with their unique Request Form No
            $insertVisitorDetailSql = "INSERT INTO visitor_details (Visitor_ID, Name, Email, Phone, ic, vehicle_reg_no, created_by, created_date, status, Request_Form_No) 
                                       VALUES ('$visitor_id', '$name', '$email', '$phone', '$ic', '$vehicle_reg_no', '$created_by', NOW(), 'Pending', '$request_form_no')";
            mysqli_query($db, $insertVisitorDetailSql);
        }

        // Fetch visitor and host information to send email
        $visitorSql = "SELECT v.ID, v.General_Email, v.Visitor_Type, v.Purpose, v.Host, v.Meeting_Room, v.Approver, v.Plan_Date_Time_In, v.Plan_Date_Time_Out, vd.Name, vd.Email 
                       FROM visitors v
                       JOIN visitor_details vd ON v.ID = vd.Visitor_ID
                       WHERE v.ID = '$visitor_id'";

        $result = mysqli_query($db, $visitorSql);
        if ($row = mysqli_fetch_assoc($result)) {
            $visitor_name = $row['Name'];
            $visitor_email = $row['Email'];
            $visitor_type = $row['Visitor_Type'];
            $purpose = $row['Purpose'];
            $plan_date_time_in = $row['Plan_Date_Time_In'];
            $plan_date_time_out = $row['Plan_Date_Time_Out'];
            $meeting_room = $row['Meeting_Room'];
            $host = $row['Host'];
            $general_email = $row['General_Email']; // Host's general email

            // Prepare email content
            $subject = "Visitor Registration Pending Approval";
            $body = "
            <html>
            <head>
                <title>Visitor Registration Pending</title>
            </head>
            <body>
                <p>Your visitor registration has been successfully submitted and is now pending approval.</p>
                <p><strong>Visitor Information:</strong></p>
                <ul>
                    <li><strong>Request Form No:</strong> $request_form_no</li>
                    <li><strong>Visitor Type:</strong> $visitor_type</li>
                    <li><strong>Purpose:</strong> $purpose</li>
                    <li><strong>Planned Date & Time In:</strong> $plan_date_time_in</li>
                    <li><strong>Planned Date & Time Out:</strong> $plan_date_time_out</li>
                    <li><strong>Meeting Room:</strong> $meeting_room</li>
                    <li><strong>Name of Host/Interviewer:</strong> $host</li>
                </ul>
                <p>Thank you!</p>
            </body>
            </html>";

            // Prepare the list of all visitor emails
            $recipientEmails = $visitor_emails; // This will be an array of all visitor emails

            // Send the email to all visitors and CC the host
            $mail = new PHPMailer(true);
            try {
                // SMTP configuration
                $mail->isSMTP();
                $mail->Host = 'mail.umedichealthcare.com';
                $mail->SMTPAuth = true;
                $mail->Username = 'farzana@umedichealthcare.com';
                $mail->Password = '385003&+Umc'; // Use environment variables for security
                $mail->SMTPSecure = 'ssl';
                $mail->Port = 465;
                $mail->SMTPDebug = 0;

                // Send the email to all visitors in the "To" field and CC the host's general email
                if (sendEmail($mail, $recipientEmails, $subject, $body, null, $general_email)) {
                    // If email is sent successfully, redirect to a success page or confirmation page
                    header('Location: thank_you.php'); // Redirect to a thank you page or some confirmation page
                    exit;
                } else {
                    echo "Error sending email to visitors.";
                }
            } catch (Exception $e) {
                echo "Error: " . $e->getMessage();
            }
        } else {
            echo "Error fetching visitor details from the database.";
        }
    } else {
        echo "Error: " . mysqli_error($db);
    }
}
?>
