<?php
// Include your database connection file
include('dbconn.php');

// Set the timezone to Malaysia time
date_default_timezone_set('Asia/Kuala_Lumpur');

// Get the visitor ID from the query string
$visitor_id = isset($_GET['visitor_id']) ? mysqli_real_escape_string($db, $_GET['visitor_id']) : null;

if ($visitor_id) {
    // First, check the regular visitors table (visitor_details) and join with the visitors table
    $sql_visitor = "
        SELECT vd.*, vi.Visitor_Type, vi.Meeting_Room
        FROM visitor_details vd
        LEFT JOIN visitors vi ON vd.ID = vi.ID
        WHERE vd.ID = '$visitor_id'
    ";
    $result_visitor = mysqli_query($db, $sql_visitor);

    if ($result_visitor && mysqli_num_rows($result_visitor) > 0) {
        $visitor = mysqli_fetch_assoc($result_visitor);
        $visitor_type = 'regular';  // Regular visitor type
    } else {
        // If not found in visitor_details, check in the walk-in visitors table and fetch data
        $sql_walkin = "
            SELECT w.*, w.visitor_type, w.meeting_room, w.visit_date
            FROM walkin_visitors w
            WHERE w.ID = '$visitor_id'
        ";
        $result_walkin = mysqli_query($db, $sql_walkin);

        if ($result_walkin && mysqli_num_rows($result_walkin) > 0) {
            $visitor = mysqli_fetch_assoc($result_walkin);
            $visitor_type = 'walkin';  // Walk-in visitor type
        } else {
            echo "Visitor not found.";
            exit;
        }
    }
} else {
    echo "No visitor ID provided.";
    exit;
}

// Handle the "Arrive" and "Leave" button actions
if (isset($_POST['arrive'])) {
    $arrive_time = date('Y-m-d H:i:s'); // Current timestamp for arrival in Malaysia time
    
    if ($visitor_type === 'regular') {
        $update_sql = "UPDATE visitor_details SET Arrive = '$arrive_time', status = 'arrived' WHERE ID = '$visitor_id'";
    } else {
        $update_sql = "UPDATE walkin_visitors SET Arrive = '$arrive_time', status = 'arrived' WHERE ID = '$visitor_id'";
    }

    if (mysqli_query($db, $update_sql)) {
        header("Location: visitor_details.php?visitor_id=$visitor_id"); // Redirect to reload the page with updated details
        exit;
    } else {
        echo "Error updating arrival time: " . mysqli_error($db);
    }
}

if (isset($_POST['leave'])) {
    $leave_time = date('Y-m-d H:i:s'); // Current timestamp for leave in Malaysia time
    
    if ($visitor_type === 'regular') {
        $update_sql = "UPDATE visitor_details SET Leave_Time = '$leave_time', status = 'left' WHERE ID = '$visitor_id'";
    } else {
        $update_sql = "UPDATE walkin_visitors SET Leave_Time = '$leave_time', status = 'left' WHERE ID = '$visitor_id'";
    }

    if (mysqli_query($db, $update_sql)) {
        header("Location: visitor_details.php?visitor_id=$visitor_id"); // Redirect to reload the page with updated details
        exit;
    } else {
        echo "Error updating leave time: " . mysqli_error($db);
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Visitor Details</title>
    <style>
        /* General reset */
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        body {
            font-family: 'Arial', sans-serif;
            background-color: #f4f6f9;
            color: #333;
            line-height: 1.6;
        }

        .form-container {
            width: 100%;
            max-width: 800px;
            margin: 40px auto;
            padding: 40px;
            background: #ffffff;
            border-radius: 8px;
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1);
        }

        h2 {
            font-size: 24px;
            margin-bottom: 20px;
            color: #0066cc;
            font-weight: 600;
        }

        h3 {
            font-size: 20px;
            margin-bottom: 15px;
            color: #333;
            font-weight: 600;
            position: relative;
            display: inline-block; 
        }
        
        h3::after {
        content: ''; 
        position: absolute;
        left: 0;
        bottom: 0;
        width: 100%;
        height: 2px; /* Thickness of the underline */
        background-color: #000; /* Color of the underline */
    }

        p {
            font-size: 16px;
            margin-bottom: 8px;
            color: #555;
        }

        strong {
            color: #333;
        }

        .action-button {
            background-color: #0066cc;
            color: white;
            padding: 12px 20px;
            font-size: 16px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            transition: background-color 0.3s ease;
            margin-top: 20px;
            margin-right:100%;
        }

        .action-button:hover {
            background-color: #005bb5;
        }

        .back-link {
            margin-top: 25px;
            display: inline-block;
            text-decoration: none;
            color: #0066cc;
            font-weight: 500;
            padding: 8px 16px;
            border: 1px solid #0066cc;
            border-radius: 4px;
            transition: all 0.3s ease;
        }

        .back-link:hover {
            background-color: #0066cc;
            color: white;
        }

        .button-container {
            text-align: center;
        }

        /* Responsive design */
        @media (max-width: 600px) {
            .form-container {
                padding: 20px;
            }

            h2, h3 {
                font-size: 20px;
            }

            p {
                font-size: 14px;
            }

            .action-button {
                width: 100%;
                padding: 14px;
                font-size: 18px;
            }

            .back-link {
                width: 100%;
                text-align: center;
            }
        }
    </style>
</head>
<body>

<div class="form-container">
    <h2>Visitor Details</h2>

    <!-- Regular Visitor Details -->
    <?php if ($visitor_type === 'regular'): ?>
        <h3>Pre-Registration Visitor</h3>
        <p><strong>Name:</strong> <?php echo htmlspecialchars($visitor['Name']); ?></p>
        <p><strong>Email:</strong> <?php echo htmlspecialchars($visitor['Email']); ?></p>
        <p><strong>Phone:</strong> <?php echo htmlspecialchars($visitor['Phone']); ?></p>

        <p><strong>Visitor Type:</strong> <?php echo htmlspecialchars($visitor['Visitor_Type'] ? $visitor['Visitor_Type'] : 'N/A'); ?></p>
        <p><strong>Meeting Room:</strong> <?php echo htmlspecialchars($visitor['Meeting_Room'] ? $visitor['Meeting_Room'] : 'N/A'); ?></p>

        <p><strong>Status:</strong> <?php echo htmlspecialchars($visitor['status']); ?></p>
        <p><strong>Arrival Time:</strong> <?php echo htmlspecialchars($visitor['Arrive'] !== null ? $visitor['Arrive'] : 'N/A'); ?></p>
        <p><strong>Leave Time:</strong> <?php echo htmlspecialchars($visitor['Leave_Time'] !== null ? $visitor['Leave_Time'] : 'N/A'); ?></p>

        <!-- Buttons for Arriving and Leaving -->
        <?php if ($visitor['status'] === 'pending'): ?>
            <form method="POST" class="button-container">
                <button type="submit" name="arrive" class="action-button">Arrive</button>
            </form>
        <?php elseif ($visitor['status'] === 'arrived'): ?>
            <form method="POST" class="button-container">
                <button type="submit" name="leave" class="action-button">Leave</button>
            </form>
        <?php endif; ?>

    <?php endif; ?>

    <!-- Walk-in Visitor Details -->
    <?php if ($visitor_type === 'walkin'): ?>
        <h3>Walk-in Visitor</h3>
        <p><strong>Name:</strong> <?php echo htmlspecialchars($visitor['name']); ?></p>
        <p><strong>Email:</strong> <?php echo htmlspecialchars($visitor['email']); ?></p>
        <p><strong>Phone:</strong> <?php echo htmlspecialchars($visitor['phone']); ?></p>
        <p><strong>Visitor Type:</strong> <?php echo htmlspecialchars($visitor['visitor_type']); ?></p>
        <p><strong>Meeting Room:</strong> <?php echo htmlspecialchars($visitor['meeting_room']); ?></p>
        <p><strong>Visit Date:</strong> <?php echo htmlspecialchars($visitor['visit_date']); ?></p>
        <p><strong>Status:</strong> <?php echo htmlspecialchars($visitor['status']); ?></p>
        <p><strong>Arrival Time:</strong> <?php echo htmlspecialchars($visitor['Arrive'] !== null ? $visitor['Arrive'] : 'N/A'); ?></p>
        <p><strong>Leave Time:</strong> <?php echo htmlspecialchars($visitor['Leave_Time'] !== null ? $visitor['Leave_Time'] : 'N/A'); ?></p>

        <!-- Buttons for Arriving and Leaving -->
        <?php if ($visitor['status'] === 'pending'): ?>
            <form method="POST" class="button-container">
                <button type="submit" name="arrive" class="action-button">Arrive</button>
            </form>
        <?php elseif ($visitor['status'] === 'arrived'): ?>
            <form method="POST" class="button-container">
                <button type="submit" name="leave" class="action-button">Leave</button>
            </form>
        <?php endif; ?>

    <?php endif; ?>

    <a href="scan_qr_detail_0.php" class="back-link">Back to Visitor List</a>
</div>

</body>
</html>
