<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Walk-In Visitor Registration</title>
    <style>
        body {
            font-family: 'Poppins', sans-serif;
            background-color: #f5f7fa;
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            min-height: 100vh;
        }

        .form-container {
            width: 100%;
            max-width: 600px; /* Max width for the form container */
            background-color: white;
            padding: 20px; /* Reduced padding around the form */
            border-radius: 10px;
            box-shadow: 0 6px 20px rgba(0, 0, 0, 0.1);
            margin: auto;
            border: 1px solid #ddd; /* Lighter border for better visual appeal */
        }

        .form-title {
            background-color: #2e4053;
            color: #ffffff;
            padding: 18px;
            text-align: center;
            font-size: 28px; /* Slightly smaller title font */
            font-weight: bold;
            margin-bottom: 20px; /* Reduced margin between title and form fields */
            border-radius: 10px;
            text-shadow: 1px 1px 3px rgba(0, 0, 0, 0.1);
        }

        .form-group {
            display: flex;
            flex-direction: column; /* Stack form fields vertically */
            margin-bottom: 15px; /* Reduced space between fields */
        }

        .custom-label {
            font-weight: bold;
            margin-bottom: 6px; /* Reduced spacing below the label */
            display: block;
            color: #333;
            font-size: 14px; /* Smaller font size for labels */
            text-align: left;
        }

        .form-group input[type="text"],
        .form-group input[type="email"],
        .form-group input[type="tel"],
        .form-group input[type="datetime-local"],
        .form-group select,
        .form-group textarea {
            width: 100%;
            padding: 10px; /* Reduced padding */
            font-size: 14px; /* Smaller font size for input text */
            border: 1px solid #ddd;
            border-radius: 8px;
            background-color: #fafafa;
            transition: all 0.3s ease;
            margin-top: 5px; /* Slight margin between label and input */
        }

        .form-group input[type="text"]:focus,
        .form-group input[type="email"]:focus,
        .form-group input[type="tel"]:focus,
        .form-group input[type="datetime-local"]:focus,
        .form-group select:focus,
        .form-group textarea:focus {
            border-color: #c62828;
            box-shadow: 0 0 8px rgba(198, 40, 40, 0.5);
            outline: none;
        }

        /* Textarea styling */
        .form-group textarea {
            min-height: 100px; /* Slightly smaller height */
            resize: vertical; /* Allow vertical resize */
        }

        .submit-button {
            padding: 6px 14px;  /* Reduced padding */
            width: 120px;        /* Slightly reduced width */
            background-color: #cf0000;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            transition: background-color 0.3s, transform 0.2s;
            margin-left: 79%;
        }

        .submit-button:hover {
            background-color: grey;
            transform: translateY(-2px);
        }

        .form-footer {
            text-align: center;
            margin-top: 15px;
            font-size: 12px; /* Smaller footer font */
            color: #777;
        }

        .form-footer a {
            color: #c62828;
            text-decoration: none;
        }

        .form-footer a:hover {
            text-decoration: underline;
        }

        hr {
            border: 1px solid #ddd;
            margin: 15px 0;
        }

        /* Responsive design */
        @media (max-width: 768px) {
            .form-container {
                padding: 15px; /* Reduced padding for smaller screens */
            }

            .form-title {
                font-size: 24px; /* Smaller title font on mobile */
            }

            .form-group input[type="text"],
            .form-group input[type="email"],
            .form-group input[type="tel"],
            .form-group input[type="datetime-local"],
            .form-group select,
            .form-group textarea {
                font-size: 12px; /* Smaller font size for mobile */
                padding: 8px; /* Slightly smaller padding */
            }

            .submit-button {
                font-size: 14px; /* Smaller button font for mobile */
                padding: 10px; /* Smaller padding */
            }
        }
    </style>
</head>
<body>

    <div class="form-container">
        <div class="form-title">
            Walk-In Visitor Registration
        </div>

        <form action="visitor_action2.php" method="POST">
            <div class="form-group">
                <label class="custom-label" for="name">Name:</label>
                <input type="text" id="name" name="name" placeholder="Enter your name" required>
            </div>

            <div class="form-group">
                <label class="custom-label" for="email">Email:</label>
                <input type="email" id="email" name="email" placeholder="Enter your email" required>
            </div>

            <div class="form-group">
                <label class="custom-label" for="phone">Phone Number:</label>
                <input type="tel" id="phone" name="phone" placeholder="Enter your phone number" required>
            </div>

            <div class="form-group">
                <label class="custom-label" for="visitor_type">Visitor Type:</label>
                <select name="visitor_type" id="visitor_type" required>
                    <option value="">Select Visitor Type</option>
                    <?php
                    include('visitor_types.php');
                    $visitorTypes = getVisitorTypes();
                    foreach ($visitorTypes as $type) {
                        echo "<option value='" . htmlspecialchars($type) . "'>" . htmlspecialchars($type) . "</option>";
                    }
                    ?>
                </select>
            </div>

            <div class="form-group">
                <label class="custom-label" for="meeting_room">Location:</label>
                <select name="meeting_room" id="meeting_room" required>
                    <option value="">Select Location</option>
                    <?php
                    include('meeting_rooms.php');
                    $meetingRooms = getMeetingRooms();
                    foreach ($meetingRooms as $room) {
                        echo "<option value='" . htmlspecialchars($room['type_name']) . "'>" . htmlspecialchars($room['type_name']) . "</option>";
                    }
                    ?>
                </select>
            </div>

            <div class="form-group">
                <label class="custom-label" for="visit_date">Date and Time of Visit:</label>
                <input type="datetime-local" id="visit_date" name="visit_date" required>
            </div>

            <button type="submit" class="submit-button">Submit</button>
        </form>

    </div>

</body>
</html>
